Index: mathtext.py
===================================================================
--- mathtext.py	(revision 2527)
+++ mathtext.py	(working copy)
@@ -145,8 +145,10 @@
         latex_to_standard
 from matplotlib.numerix import absolute
 from matplotlib import get_data_path, rcParams
+# Edin's imports
+from matplotlib.tex2uni import tex2uni
+from matplotlib.type12uni import type12uni
 
-
 bakoma_fonts = []
 
 # symbols that have the sub and superscripts over/under 
@@ -163,6 +165,36 @@
     r'\angstrom' : (  ('rm', 'A', 1.0), (None, '\circ', 0.5), 0.0 ),
     }
 
+
+# Functions defined by Edin
+def font_open(filename):
+    ext = filename.rsplit('.',1)[1]
+    if ext == 'afm':
+        return AFM(filename)
+    else:
+        return FT2Font(filename)
+
+def get_unicode_index(symbol):
+    """get_unicode_index(symbol) -> integer
+
+Return the integer index (from the Unicode table) of an Unicode symbol
+"""
+    try:# This will succeed if symbol is a single unicode char
+        return ord(symbol)
+    except TypeError:
+        pass
+    try:# Is symbol a TeX symbol (i.e. \alpha)
+        return tex2uni[symbol]
+    except KeyError:
+        pass
+    try:# Is symbol a Type1 name (i.e. degree)? If not raise error
+        return type12uni[symbol]
+    except KeyError:
+        message = """'%(symbol)s' is not a valid Unicode character or
+TeX/Type1 symbol"""%locals()
+        raise ValueError, message
+
+
 class Fonts:
     """
     An abstract base class for fonts that want to render mathtext
@@ -171,11 +203,11 @@
     return the character metrics as well as do the drawing
     """
 
-    def get_kern(self, font, symleft, symright, fontsize, dpi):
+    def get_kern(self, facename, symleft, symright, fontsize, dpi):
         """
         Get the kerning distance for font between symleft and symright.
 
-        font is one of tt, it, rm, cal or None
+        facename is one of tt, it, rm, cal or None
 
         sym is a single symbol(alphanum, punct) or a special symbol
         like \sigma.
@@ -183,9 +215,9 @@
         """
         return 0
     
-    def get_metrics(self, font, sym, fontsize, dpi):
+    def get_metrics(self, facename, sym, fontsize, dpi):
         """
-        font is one of tt, it, rm, cal or None
+        facename is one of tt, it, rm, cal or None
 
         sym is a single symbol(alphanum, punct) or a special symbol
         like \sigma.
@@ -207,7 +239,7 @@
         'Dimension the drawing canvas; may be a noop'
         self.width, self.height = w, h
 
-    def render(self, ox, oy, font, sym, fontsize, dpi):
+    def render(self, ox, oy, facename, sym, fontsize, dpi):
         pass
 
 
@@ -226,6 +258,231 @@
             )
         return metrics
 
+
+class UnicodeFonts(Fonts):
+    """An abstract base class for handling Unicode fonts.
+
+Specific terminology:
+ * fontface: an FT2Font object, corresponding to a facename
+ * facename: a string that defines the (type)face's name - 'rm', 'it' etc.
+ * filename: a string that is used for generating a fontface object
+ * symbol*: a single Unicode character or a TeX command,
+    or to be precise, a TeX symbol command like \alpha (but not \frac) or
+    even a Type1/PS name
+ * facefiledict: a dict that maps the face's name to the filename:
+    facefiledict = { 'cal' : 'fontnamecal.ext',
+                  'rm'  : 'fontnamerm.ext',
+                  'tt'  : 'fontnamett.ext',
+                  'it'  : 'fontnameit.ext',
+                  None  : 'fontnamesmth.ext'}
+    facefiledict should be declared as a class atribute
+ * glyphdict: a dict used for caching of glyph specific data
+ * fonts: a dict of facename -> fontface pairs
+ * charmaps: a dict of facename -> charmap pairs
+ * glyphmaps: a dict of facename -> glyphmap pairs. A glyphmap is an
+    inverted charmap
+ * output: a string in ['BMP','SVG','PS'], coresponding to the backends
+ * index: Fontfile specific index of a glyph/char. Taken from a charmap.
+
+"""
+
+    # The path to the dir with the fontfiles
+    basepath = get_data_path()
+    
+    def __init__(self, output='BMP'):
+        self.facenames = self.facefiledict.keys()
+        if output:
+            self.output = output
+        # dict self.glyphdict[key] = facename, metrics, glyph, offset
+        self.glyphdict = {}
+        
+        self.fonts = dict(
+            [ (facename, font_open(os.path.join(self.basepath,
+                self.facefiledict[facename]))) for facename in
+                                                self.facenames])
+        # a dict of glyphindex -> charcode pairs
+        self.charmaps = dict(
+            [ (facename, self.fonts[facename].get_charmap())\
+                for facename in self.facenames])
+        # a dict of charcode -> glyphindex pairs
+        self.glyphmaps = {}
+        for facename in self.facenames:
+            charmap = self.charmaps[facename]
+            self.glyphmaps[facename] = dict([(charcode, glyphind)
+                for glyphind, charcode in charmap.items()])
+        for fontface in self.fonts.values():
+            fontface.clear()
+        if self.output == 'SVG':
+            # a list of "glyphs" we need to render this thing in SVG
+            self.svg_glyphs=[]
+
+    def set_canvas_size(self, w, h, pswriter=None):
+        'Dimension the drawing canvas; may be a noop'
+        # self.width = int(w)
+        # self.height = int(h)
+        # I don't know why this was different than the PS version
+        self.width = w
+        self.height = h
+        if pswriter:
+            self.pswriter = pswriter
+        else:
+            for fontface in self.fonts.values():
+                fontface.set_bitmap_size(int(w), int(h))
+
+    def render(self, ox, oy, facename, symbol, fontsize, dpi):
+        filename = self.facefiledict[facename]
+        uniindex, metrics, glyph, offset = self._get_info(facename,
+                                                    symbol, fontsize, dpi)
+        if self.output == 'SVG':
+            oy += offset - 512/2048.*10.
+            # TO-DO - make a method for it
+            # This gets the name of the font.
+            familyname = self.fonts[facename].get_sfnt()[(1,0,0,1)]
+            self.svg_glyphs.append((familyname, fontsize, uniindex, ox, oy,
+                                                            metrics))
+        elif self.output == 'PS':
+            # This should be changed to check for math mode or smth.
+            #if filename == 'cmex10.ttf':
+            #    oy += offset - 512/2048.*10.
+            psfontname = self.fonts[facename].postscript_name
+            glyphname = symbol
+            ps = """/%(psfontname)s findfont
+%(fontsize)s scalefont
+setfont
+%(ox)f %(oy)f moveto
+/%(glyphname)s glyphshow
+""" % locals()
+            self.pswriter.write(ps)
+        else: # BMP
+            fontface = self.fonts[facename]
+            fontface.draw_glyph_to_bitmap(
+            int(ox),  int(self.height - oy - metrics.ymax), glyph)
+
+    def get_metrics(self, facename, symbol, fontsize, dpi):
+        uniindex, metrics, glyph, offset  = \
+                self._get_info(facename, symbol, fontsize, dpi) 
+        return metrics
+
+    def _get_unicode_index(self, symbol):
+        return get_unicode_index(symbol)
+
+    def _get_info(self, facename, symbol, fontsize, dpi):
+        'load the facename, metrics and glyph'
+        #print hex(index), symbol, filename, facename
+        key = facename, symbol, fontsize, dpi
+        tup = self.glyphdict.get(key)
+        if tup is not None:
+            return tup
+        filename = self.facefiledict[facename]
+        # This is black magic to me (Edin)
+        if self.output == 'PS':
+            if filename not in bakoma_fonts:
+                bakoma_fonts.append(filename)
+        fontface = self.fonts[facename]
+        fontface.set_size(fontsize, dpi)
+        head  = fontface.get_sfnt_table('head')
+        uniindex = self._get_unicode_index(symbol)
+        glyphindex = self.glyphmaps[facename][uniindex]
+        #print glyphindex, uniindex
+        #glyph = fontface.load_char(glyphindex)
+        glyph = fontface.load_char(uniindex)
+        xmin, ymin, xmax, ymax = [val/64.0 for val in glyph.bbox]
+        # This is black magic to me (Edin)
+        if filename == 'cmex10.ttf':
+            if self.output == 'PS':
+                offset = -(head['yMin']+512)/head['unitsPerEm']*10.
+            else:
+                offset =  glyph.height/64.0/2 + 256.0/64.0*dpi/72.0
+        else:
+            offset = 0.
+        metrics = Bunch(
+            advance  = glyph.linearHoriAdvance/65536.0,
+            height   = glyph.height/64.0,
+            width    = glyph.width/64.0,
+            xmin = xmin,
+            xmax = xmax,
+            ymin = ymin+offset,
+            ymax = ymax+offset,
+            )
+        self.glyphdict[key] = uniindex, metrics, glyph, offset
+        return self.glyphdict[key]
+
+
+class MyUnicodeFonts(UnicodeFonts):
+    basepath = r'C:\WINDOWS\Fonts'
+    facefiledict = { 'cal' : 'KUNSTLER.TTF',
+                'rm'  : 'times.ttf',
+                'tt'  : 'cour.ttf',
+                'it'  : 'ARIALUNI.TTF',
+                None  : 'ARIALUNI.TTF',
+                }
+
+
+# Doesn't work yet
+class BakomaUnicodeFonts(UnicodeFonts):
+    """A class that simulates Unicode support in the BaKoMa fonts"""
+
+    facefiledict = { 'cal' : 'cmsy10.ttf',
+                'rm'  : 'cmr10.ttf',
+                'tt'  : 'cmtt10.ttf',
+                'it'  : 'cmmi10.ttf',
+                None  : 'cmmi10.ttf',
+                }
+
+    def _get_info(self, facename, symbol, fontsize, dpi):
+        'load the facename, metrics and glyph'
+        #print hex(index), symbol, filename, facename
+        key = facename, symbol, fontsize, dpi
+        tup = self.glyphdict.get(key)
+        if tup is not None:
+            return tup
+
+        filename = self.facefiledict[facename]
+        # This is black magic to me (Edin)
+        if self.output == 'PS':
+            if filename not in bakoma_fonts:
+                bakoma_fonts.append(filename)
+        fontface = self.fonts[facename]
+        fontface.set_size(fontsize, dpi)
+        head  = fontface.get_sfnt_table('head')
+        index = self._get_index(symbol)
+        glyph = fontface.load_char(index)
+        xmin, ymin, xmax, ymax = [val/64.0 for val in glyph.bbox]
+        # This is black magic to me (Edin)
+        if filename == 'cmex10.ttf':
+            if self.output == 'PS':
+                offset = -(head['yMin']+512)/head['unitsPerEm']*10.
+            else:
+                offset =  glyph.height/64.0/2 + 256.0/64.0*dpi/72.0
+        else:
+            offset = 0.
+        metrics = Bunch(
+            advance  = glyph.linearHoriAdvance/65536.0,
+            height   = glyph.height/64.0,
+            width    = glyph.width/64.0,
+            xmin = xmin,
+            xmax = xmax,
+            ymin = ymin+offset,
+            ymax = ymax+offset,
+            )
+        self.glyphdict[key] = metrics, glyph, offset
+        return self.glyphdict[key]
+
+    # We override the UnicodeFonts method
+    def _get_unicode_index(self, symbol):
+        pass
+
+
+class CMUUnicodeFonts(UnicodeFonts):
+    """A class representing Computer Modern Unicode Fonts, made by
+Andrey V. Panov
+panov /at/ canopus. iacp. dvo. ru
+They are distributed under the X11 License.
+
+TO-DO: Implement all methods :)
+"""
+
+
 class TrueTypeFonts(Fonts):
     def __init__(self):
 
@@ -1312,7 +1569,7 @@
 
 
 
-def math_parse_s_ft2font(s, dpi, fontsize, angle=0):
+class math_parse_s_ft2font_common:
     """
     Parse the math expression s, return the (bbox, fonts) tuple needed
     to render it.
@@ -1321,152 +1578,84 @@
 
     return is width, height, fonts
     """
-
     major, minor1, minor2, tmp, tmp = sys.version_info
     if major==2 and minor1==2:
         raise SystemExit('mathtext broken on python2.2.  We hope to get this fixed soon')
 
-    cacheKey = (s, dpi, fontsize, angle)
-    s = s[1:-1]  # strip the $ from front and back
-    if math_parse_s_ft2font.cache.has_key(cacheKey):
-        w, h, bfonts = math_parse_s_ft2font.cache[cacheKey]
-        return w, h, bfonts.fonts.values()
+    def __init__(self, output):
+        self.output = output
+        self.cache = {}
+        
+    def __call__(self, s, dpi, fontsize, angle=0):
+        cacheKey = (s, dpi, fontsize, angle)
+        s = s[1:-1]  # strip the $ from front and back
+        if self.cache.has_key(cacheKey):
+            w, h, fontlike = self.cache[cacheKey]
+            return w, h, fontlike
+        if self.output == 'SVG':
+            self.font_object = BakomaTrueTypeFonts(useSVG=True)
+            #self.font_object = MyUnicodeFonts(output='SVG')
+            Element.fonts = self.font_object
+        elif self.output == 'PNG':
+            self.font_object = BakomaTrueTypeFonts()
+            #self.font_object = MyUnicodeFonts()
+            Element.fonts = self.font_object
+        elif self.output == 'PS':
+            if rcParams['ps.useafm']:
+                self.font_object = StandardPSFonts()
+                Element.fonts = self.font_object
+            else:
+                self.font_object = BakomaPSFonts()
+                #The following line doesn't work when uncommented
+                #self.font_object = ArialUnicodeFonts(output='PS')
+                Element.fonts = self.font_object
+        
+        handler.clear()
+        expression.parseString( s )
 
-    bakomaFonts = BakomaTrueTypeFonts()
-    Element.fonts = bakomaFonts
-    handler.clear()
-    expression.parseString( s )
+        handler.expr.set_size_info(fontsize, dpi)
 
-    handler.expr.set_size_info(fontsize, dpi)
+        # set the origin once to allow w, h compution
+        handler.expr.set_origin(0, 0)
+        xmin = min([e.xmin() for e in handler.symbols])
+        xmax = max([e.xmax() for e in handler.symbols])
+        ymin = min([e.ymin() for e in handler.symbols])
+        ymax = max([e.ymax() for e in handler.symbols])
 
-    # set the origin once to allow w, h compution
-    handler.expr.set_origin(0, 0)
-    xmin = min([e.xmin() for e in handler.symbols])
-    xmax = max([e.xmax() for e in handler.symbols])
-    ymin = min([e.ymin() for e in handler.symbols])
-    ymax = max([e.ymax() for e in handler.symbols])
+        # now set the true origin - doesn't affect with and height
+        w, h =  xmax-xmin, ymax-ymin
+        # a small pad for the canvas size
+        w += 2
+        h += 2
 
-    # now set the true origin - doesn't affect with and height
-    w, h =  xmax-xmin, ymax-ymin
-    # a small pad for the canvas size
-    w += 2
-    h += 2
+        handler.expr.set_origin(0, h-ymax)
 
-    handler.expr.set_origin(0, h-ymax)
+        if self.output == 'SVG':
+            Element.fonts.set_canvas_size(w,h)
+        elif self.output == 'PNG':
+            Element.fonts.set_canvas_size(w,h)
+        elif self.output == 'PS':
+            pswriter = StringIO()
+            Element.fonts.set_canvas_size(w, h, pswriter)
+        
+        handler.expr.render()
+        handler.clear()
 
-    Element.fonts.set_canvas_size(w,h)
-    handler.expr.render()
-    handler.clear()
+        if self.output == 'SVG':
+            self.cache[cacheKey] = w, h, self.font_object.svg_glyphs
+            return w, h, self.font_object.svg_glyphs
+        elif self.output == 'PNG':
+            self.cache[cacheKey] = w, h, self.font_object.fonts.values()
+            return w, h, self.font_object.fonts.values()
+        elif self.output == 'PS':
+            self.cache[cacheKey] = w, h, pswriter
+            return w, h, pswriter
 
-    math_parse_s_ft2font.cache[cacheKey] = w, h, bakomaFonts
-    return w, h, bakomaFonts.fonts.values()
+math_parse_s_ft2font = math_parse_s_ft2font_common('PNG')
+math_parse_s_ft2font_svg = math_parse_s_ft2font_common('SVG')
+math_parse_s_ps = math_parse_s_ft2font_common('PS')
 
-math_parse_s_ft2font.cache = {}
 
-def math_parse_s_ft2font_svg(s, dpi, fontsize, angle=0):
-    """
-    Parse the math expression s, return the (bbox, fonts) tuple needed
-    to render it.
-
-    fontsize must be in points
-
-    return is width, height, fonts
-    """
-
-    major, minor1, minor2, tmp, tmp = sys.version_info
-    if major==2 and minor1==2:
-        print >> sys.stderr, 'mathtext broken on python2.2.  We hope to get this fixed soon'
-        sys.exit()
-    cacheKey = (s, dpi, fontsize, angle)
-    s = s[1:-1]  # strip the $ from front and back
-    if math_parse_s_ft2font_svg.cache.has_key(cacheKey):
-        w, h, svg_glyphs = math_parse_s_ft2font_svg.cache[cacheKey]
-        return w, h, svg_glyphs
-
-    bakomaFonts = BakomaTrueTypeFonts(useSVG=True)
-    Element.fonts = bakomaFonts
-    handler.clear()
-    expression.parseString( s )
-
-    handler.expr.set_size_info(fontsize, dpi)
-
-    # set the origin once to allow w, h compution
-    handler.expr.set_origin(0, 0)
-    xmin = min([e.xmin() for e in handler.symbols])
-    xmax = max([e.xmax() for e in handler.symbols])
-    ymin = min([e.ymin() for e in handler.symbols])
-    ymax = max([e.ymax() for e in handler.symbols])
-
-    # now set the true origin - doesn't affect with and height
-    w, h =  xmax-xmin, ymax-ymin
-    # a small pad for the canvas size
-    w += 2
-    h += 2
-
-    handler.expr.set_origin(0, h-ymax)
-
-    Element.fonts.set_canvas_size(w,h)
-    handler.expr.render()
-    handler.clear()
-
-    math_parse_s_ft2font_svg.cache[cacheKey] = w, h, bakomaFonts.svg_glyphs
-    return w, h, bakomaFonts.svg_glyphs
-
-math_parse_s_ft2font_svg.cache = {}
-
-
-def math_parse_s_ps(s, dpi, fontsize):
-    """
-    Parse the math expression s, return the (bbox, fonts) tuple needed
-    to render it.
-
-    fontsize must be in points
-
-    return is width, height, fonts
-
-    """
-    cacheKey = (s, dpi, fontsize)
-    s = s[1:-1]  # strip the $ from front and back
-    if math_parse_s_ps.cache.has_key(cacheKey):
-        w, h, pswriter = math_parse_s_ps.cache[cacheKey]
-        return w, h, pswriter
-
-    if rcParams['ps.useafm']:
-        standardFonts = StandardPSFonts()
-        Element.fonts = standardFonts
-    else:
-        bakomaFonts = BakomaPSFonts()
-        Element.fonts = bakomaFonts
-    handler.clear()
-    expression.parseString( s )
-
-    handler.expr.set_size_info(fontsize, dpi)
-
-    # set the origin once to allow w, h compution
-    handler.expr.set_origin(0, 0)
-    xmin = min([e.xmin() for e in handler.symbols])
-    xmax = max([e.xmax() for e in handler.symbols])
-    ymin = min([e.ymin() for e in handler.symbols])
-    ymax = max([e.ymax() for e in handler.symbols])
-
-    # now set the true origin - doesn't affect with and height
-    w, h =  xmax-xmin, ymax-ymin
-    # a small pad for the canvas size
-    w += 2
-    h += 2
-
-    handler.expr.set_origin(0, h-ymax)
-
-    pswriter = StringIO()
-    Element.fonts.set_canvas_size(w, h, pswriter)
-    handler.expr.render()
-    handler.clear()
-
-    math_parse_s_ps.cache[cacheKey] = w, h, pswriter
-    return w, h, pswriter
-
-math_parse_s_ps.cache = {}
-
 if 0: #__name__=='___main__':
     
     stests = [ 
Index: tex2uni.py
===================================================================
--- tex2uni.py	(revision 0)
+++ tex2uni.py	(revision 0)
@@ -0,0 +1,487 @@
+# Automatically generated file.
+# Don't edit this file. Edit _mathtext_manual_data.py instead
+
+tex2uni = {r'\maltese' : 10016,
+r'\textexclamdown' : 161,
+r'\leq' : 8804,
+r'\Uparrow' : 8657,
+r'\supset' : 8835,
+r'\divideontimes' : 8903,
+r'\succnsim' : 8937,
+r'\Doteq' : 8785,
+r'\Re' : 8476,
+r'\nearrow' : 8599,
+r'\hspace' : 8202,
+r'\vert' : 124,
+r'\clubsuit' : 9827,
+r'\measuredangle' : 8737,
+r'\eqdef' : 8797,
+r'\danger' : 9761,
+r'\asymp' : 8781,
+r'\oe' : 339,
+r'\Sigma' : 931,
+r'\tilde' : 771,
+r'\Cup' : 8915,
+r'\nsucc' : 8833,
+r'\solbar' : 9023,
+r'\doublebarwedge ?' : 8966,
+r'\BbbC' : 8450,
+r'\sqsupset' : 8848,
+r'\BbbN' : 8469,
+r'\origof' : 8886,
+r'\Psi' : 936,
+r'\BbbR' : 8477,
+r'\BbbQ' : 8474,
+r'\BbbP' : 8473,
+r'\BbbZ' : 8484,
+r'\Omega' : 937,
+r'\oiiint' : 8752,
+r'\nabla' : 8711,
+r'\succsim' : 8831,
+r'\coprod' : 8720,
+r'\blacktriangle' : 9652,
+r'\rq' : 8217,
+r'\colon' : 58,
+r'\models' : 8871,
+r'\twoheaddownarrow' : 8609,
+r'\Swarrow' : 8665,
+r'\leftarrow' : 8592,
+r'\prec' : 8826,
+r'\otimes' : 8855,
+r'\napprox' : 8777,
+r'\invnot' : 8976,
+r'\aleph' : 8501,
+r'\degree' : 176,
+r'\cdots' : 8943,
+r'\cdotp' : 183,
+r'\gtrdot' : 8919,
+r'\gnsim' : 8935,
+r'\blacktriangledown' : 9662,
+r'\questeq' : 8799,
+r'\swarrow' : 8601,
+r'\cong' : 8773,
+r'\spadesuitopen' : 9828,
+r'\equiv' : 8801,
+r'\neg' : 172,
+r'\preccurlyeq' : 8828,
+r'\lessgtr' : 8822,
+r'\ll' : 8810,
+r'\Ldsh' : 8626,
+r'\lneqq' : 8808,
+r'\updownarrows' : 8645,
+r'\star' : 8902,
+r'\Nearrow' : 8663,
+r'\nparallel' : 8742,
+r'\lq' : 8216,
+r'\alpha' : 945,
+r'\clubsuitopen' : 9831,
+r'\rightrightarrows' : 8649,
+r'\mapsdown' : 8615,
+r'\risingdotseq' : 8787,
+r'\geqq' : 8807,
+r'\stareq' : 8795,
+r'\ltimes' : 8905,
+r'\leftthreetimes' : 8907,
+r'\ntriangleleft' : 8938,
+r'\carriagereturn' : 8629,
+r'\twoheadrightarrow' : 8608,
+r'\Lsh' : 8624,
+r'\Rrightarrow' : 8667,
+r'\Finv' : 8498,
+r'\uplus' : 8846,
+r'\arceq' : 8792,
+r'\ddots' : 8945,
+r'\kappa' : 954,
+r'\sigma' : 963,
+r'\Rightarrow' : 8658,
+r'\cup' : 8746,
+r'\leftrightharpoons' : 8651,
+r'\lambda' : 955,
+r'\circledcirc' : 8858,
+r'\Theta' : 920,
+r'\wr' : 8768,
+r'\wp' : 8472,
+r'\Vdash' : 8873,
+r'\varrho' : 1009,
+r'\Vert' : 8214,
+r'\coloneq' : 8788,
+r'\gtrless' : 8823,
+r'\sqcap' : 8851,
+r'\leqq' : 8806,
+r'\backsim' : 8765,
+r'\nequiv' : 8802,
+r'\varnothing' : 8709,
+r'\vartriangleright' : 8883,
+r'\beta' : 946,
+r'\nsubseteq' : 8840,
+r'\ngeq' : 8817,
+r'\leftrightarrows' : 8646,
+r'\nexists' : 8708,
+r'\Bumpeq' : 8782,
+r'\eqgtr' : 8925,
+r'\dashv' : 8867,
+r'\nRightarrow' : 8655,
+r'\dotplus' : 8724,
+r'\frakZ' : 8488,
+r'\approxeq' : 8778,
+r'\obar' : 9021,
+r'\geq' : 8805,
+r'\ncong' : 8775,
+r'\eqcolon' : 8789,
+r'\blacktriangleleft' : 9664,
+r'\searrow' : 8600,
+r'\sqsupseteq' : 8850,
+r'\bigcirc' : 9675,
+r'\vDash' : 8872,
+r'\varkappa' : 1008,
+r'\spadesuit' : 9824,
+r'\nleftrightarrow' : 8622,
+r'\nvdash' : 8876,
+r'\llcorner' : 8990,
+r'\imageof' : 8887,
+r'\mho' : 8487,
+r'\upuparrows' : 8648,
+r'\vdash' : 8866,
+r'\AE' : 198,
+r'\AA' : 8491,
+r'\prod' : 8719,
+r'\approxident' : 8779,
+r'\ss' : 223,
+r'\lbrace' : 123,
+r'\lbrack' : 91,
+r'\nsim' : 8769,
+r'\bot' : 8869,
+r'\underbar' : 817,
+r'\lessdot' : 8918,
+r'\theta' : 952,
+r'\leftrightarrow' : 8596,
+r'\psi' : 968,
+r'\curlyvee' : 8910,
+r'\not' : 824,
+r'\rightharpoonup' : 8640,
+r'\nsupseteq' : 8841,
+r'\Rsh' : 8625,
+r'\bullet' : 8729,
+r'\beth' : 8502,
+r'\varphi' : 966,
+r'\varsigma' : 962,
+r'\boxplus' : 8862,
+r'\greater' : 62,
+r'\breve' : 774,
+r'\ae' : 230,
+r'\ac' : 8766,
+r'\Delta' : 916,
+r'\curvearrowleft' : 8630,
+r'\odot' : 8857,
+r'\dot' : 775,
+r'\kernelcontraction' : 8763,
+r'\Nwarrow' : 8662,
+r'\vartriangle' : 9653,
+r'\upharpoonright' : 8638,
+r'\circ' : 8728,
+r'\dddot' : 8411,
+r'\rightarrowbar' : 8677,
+r'\gtreqless' : 8923,
+r'\frakC' : 8493,
+r'\chi' : 967,
+r'\doteq' : 8784,
+r'\sterling' : 163,
+r'\iiint' : 8749,
+r'\flat' : 9837,
+r'\upsilon' : 965,
+r'\rtimes' : 8906,
+r'\enspace' : 8194,
+r'\Phi' : 934,
+r'\wedgeq' : 8793,
+r'\mapsup' : 8613,
+r'\varpi' : 982,
+r'\bigcap' : 8898,
+r'\rightleftarrows' : 8644,
+r'\Pi' : 928,
+r'\gtrsim' : 8819,
+r'\ast' : 8727,
+r'\mapsto' : 8614,
+r'\candra' : 784,
+r'\thinspace' : 8201,
+r'\oint' : 8750,
+r'\oplus' : 8853,
+r'\diamond' : 8900,
+r'\looparrowright' : 8620,
+r'\thickspace' : 8197,
+r'\ell' : 8467,
+r'\bigstar' : 9733,
+r'\mp' : 8723,
+r'\circeq' : 8791,
+r'\ddagger' : 8225,
+r'\simeq' : 8771,
+r'\nsime' : 8772,
+r'\ddot' : 776,
+r'\downdownarrows' : 8650,
+r'\nprec' : 8832,
+r'\backcong' : 8780,
+r'\nVDash' : 8879,
+r'\textasciicircum' : 94,
+r'\bigtriangledown' : 9661,
+r'\copyright' : 169,
+r'\oslash' : 8856,
+r'\ggg' : 8921,
+r'\between' : 8812,
+r'\iint' : 8748,
+r'\nsubset' : 8836,
+r'\cdot' : 8901,
+r'\Im' : 8465,
+r'\lfloor' : 8970,
+r'\bar' : 772,
+r'\leftharpoonaccent' : 8400,
+r'\pm' : 177,
+r'\pi' : 960,
+r'\supseteq' : 8839,
+r'\nrightarrow' : 8603,
+r'\updownarrowbar' : 8616,
+r'\scurel' : 8881,
+r'\gimel' : 8503,
+r'\Subset' : 8912,
+r'\Gamma' : 915,
+r'\Vvdash' : 8874,
+r'\lll' : 8920,
+r'\blacktriangleright' : 9654,
+r'\circledS' : 9416,
+r'\circledR' : 174,
+r'\hat' : 770,
+r'\tau' : 964,
+r'\lnsim' : 8934,
+r'\overleftrightarrow' : 8417,
+r'\bumpeq' : 8783,
+r'\Updownarrow' : 8661,
+r'\propto' : 8733,
+r'\triangleleft' : 9665,
+r'\Cap' : 8914,
+r'\ntrianglelefteq' : 8940,
+r'\sqcup' : 8852,
+r'\bigcup' : 8899,
+r'\Colon' : 8759,
+r'\supsetneq' : 8843,
+r'\triangleright' : 9655,
+r'\curvearrowright' : 8631,
+r'\pitchfork' : 8916,
+r'\leftarrowtail' : 8610,
+r'\bigwedge' : 8896,
+r'\omega' : 969,
+r'\hookrightarrow' : 8618,
+r'\rightthreetimes' : 8908,
+r'\sharp' : 9839,
+r'\digamma' : 989,
+r'\slash' : 8725,
+r'\uparrow' : 8593,
+r'\veeeq' : 8794,
+r'\curlywedge' : 8911,
+r'\in' : 8712,
+r'\prurel' : 8880,
+r'\overleftarrow' : 8406,
+r'\succcurlyeq' : 8829,
+r'\eqsim' : 8770,
+r'\varepsilon' : 949,
+r'\nmid' : 8740,
+r'\cwopencirclearrow' : 8635,
+r'\zeta' : 950,
+r'\eta' : 951,
+r'\oiint' : 8751,
+r'\eth' : 240,
+r'\forall' : 8704,
+r'\urcorner' : 8989,
+r'\times' : 215,
+r'\barleftarrow' : 8676,
+r'\lrcorner' : 8991,
+r'\upharpoonleft' : 8639,
+r'\dots' : 8230,
+r'\nwarrow' : 8598,
+r'\less' : 60,
+r'\measeq' : 8798,
+r'\because' : 8757,
+r'\ddddot' : 8412,
+r'\boxminus' : 8863,
+r'\wedge' : 8743,
+r'\nVdash' : 8878,
+r'\Rdsh' : 8627,
+r'\textquestiondown' : 191,
+r'\trianglerighteq' : 8885,
+r'\rho' : 961,
+r'\Supset' : 8913,
+r'\therefore' : 8756,
+r'\diamondsuit' : 9826,
+r'\ni' : 8715,
+r'\acute' : 769,
+r'\ne' : 8800,
+r'\rightarrow' : 8594,
+r'\Xi' : 926,
+r'\iota' : 953,
+r'\nu' : 957,
+r'\div' : 247,
+r'\triangleq' : 8796,
+r'\leftleftarrows' : 8647,
+r'\rbrace' : 125,
+r'\phi' : 981,
+r'\trianglelefteq' : 8884,
+r'\ntriangleright' : 8939,
+r'\twoheadleftarrow' : 8606,
+r'\backslash' : 92,
+r'\eqless' : 8924,
+r'\rbrack' : 93,
+r'\downzigzagarrow' : 8623,
+r'\backprime' : 8245,
+r'\barwedge' : 8892,
+r'\check' : 780,
+r'\notin' : 8713,
+r'\ominus' : 8854,
+r'\precsim' : 8830,
+r'\Equiv' : 8803,
+r'\rfloor' : 8971,
+r'\turnednot' : 8985,
+r'\curlyeqsucc' : 8927,
+r'\blacksquare' : 9632,
+r'\angle' : 8736,
+r'\textquotedblright' : 8221,
+r'\sqrt' : 8730,
+r'\textasciigrave' : 96,
+r'\succ' : 8827,
+r'\subsetneq' : 8842,
+r'\nsupset' : 8837,
+r'\fallingdotseq' : 8786,
+r'\curlyeqprec' : 8926,
+r'\eqcirc' : 8790,
+r'\infty' : 8734,
+r'\rasp' : 700,
+r'\xi' : 958,
+r'\heartsuit' : 9825,
+r'\rightzigzagarrow' : 8669,
+r'\nless' : 8814,
+r'\S' : 167,
+r'\P' : 182,
+r'\veebar' : 8891,
+r'\Leftarrow' : 8656,
+r'\vartriangleleft' : 8882,
+r'\O' : 216,
+r'\L' : 321,
+r'\daleth' : 8504,
+r'\H' : 779,
+r'\acwopencirclearrow' : 8634,
+r'\t' : 865,
+r'\nleftarrow' : 8602,
+r'\ocirc' : 778,
+r'\emdash' : 8212,
+r'\sqsubset' : 8847,
+r'\vec' : 8407,
+r'\vee' : 8744,
+r'\d' : 803,
+r'\sqsubseteq' : 8849,
+r'\c' : 807,
+r'\checkmark' : 10003,
+r'\o' : 248,
+r'\l' : 322,
+r'\adots' : 8944,
+r'\k' : 808,
+r'\i' : 305,
+r'\gamma' : 947,
+r'\rceil' : 8969,
+r'\lceil' : 8968,
+r'\rightarrowtail' : 8611,
+r'\textasciiacute' : 180,
+r'\minus' : 8722,
+r'\subseteq' : 8838,
+r'\rightleftharpoons' : 8652,
+r'\Upsilon' : 978,
+r'\looparrowleft' : 8619,
+r'\updownarrow' : 8597,
+r'\grave' : 768,
+r'\intercal' : 8890,
+r'\cap' : 8745,
+r'\int' : 8747,
+r'\sim' : 8764,
+r'\prime' : 8242,
+r'\complement' : 8705,
+r'\smile' : 8995,
+r'\lesseqgtr' : 8922,
+r'\downharpoonright' : 8642,
+r'\cupdot' : 8845,
+r'\overarc' : 785,
+r'\boxbar' : 9707,
+r'\hookleftarrow' : 8617,
+r'\circleddash' : 8861,
+r'\downarrow' : 8595,
+r'\Lambda' : 923,
+r'\gg' : 8811,
+r'\ulcorner' : 8988,
+r'\lambdabar' : 411,
+r'\bigvee' : 8897,
+r'\smallsetminus' : 8726,
+r'\ntrianglerighteq' : 8941,
+r'\precnsim' : 8936,
+r'\lasp' : 701,
+r'\vdots' : 8942,
+r'\rightharpoonaccent' : 8401,
+r'\top' : 8868,
+r'\downharpoonleft' : 8643,
+r'\delta' : 948,
+r'\gneqq' : 8809,
+r'\leftharpoonup' : 8636,
+r'\mu' : 956,
+r'\parallel' : 8741,
+r'\exists' : 8707,
+r'\yen' : 165,
+r'\frown' : 8994,
+r'\approx' : 8776,
+r'\boxtimes' : 8864,
+r'\textquotedblleft' : 8220,
+r'\twoheaduparrow' : 8607,
+r'\dotminus' : 8760,
+r'\lesssim' : 8818,
+r'\rightharpoondown' : 8641,
+r'\dagger' : 8224,
+r'\backsimeq' : 8909,
+r'\partial' : 8706,
+r'\mapsfrom' : 8612,
+r'\multimap' : 8888,
+r'\OE' : 338,
+r'\circledast' : 8859,
+r'\Leftrightarrow' : 8660,
+r'\nvDash' : 8877,
+r'\mid' : 8739,
+r'\quad' : 8195,
+r'\nleq' : 8816,
+r'\sphericalangle' : 8738,
+r'\triangledown' : 9663,
+r'\ngtr' : 8815,
+r'\textasciitilde' : 126,
+r'\leftharpoondown' : 8637,
+r'\boxdot' : 8865,
+r'\scrR' : 8475,
+r'\Downarrow' : 8659,
+r'\bowtie' : 8904,
+r'\natural' : 9838,
+r'\scrE' : 8496,
+r'\scrF' : 8497,
+r'\nLeftrightarrow' : 8654,
+r'\scrB' : 8492,
+r'\scrM' : 8499,
+r'\scrL' : 8466,
+r'\nLeftarrow' : 8653,
+r'\scrI' : 8464,
+r'\scrH' : 8459,
+r'\endash' : 8211,
+r'\bigtriangleup' : 9651,
+r'\sum' : 8721,
+r'\Searrow' : 8664,
+r'\Lleftarrow' : 8666,
+r'\scre' : 8495,
+r'\scrg' : 8458,
+r'\scro' : 8500,
+r'\subset' : 8834,
+
+}
+try:
+    from _mathtext_manual_data import _tex2uni
+    tex2uni.update(_tex2uni)
+except (TypeError, SyntaxError): # Just these exceptions should be raised
+    raise
+except: # All other exceptions should be silent. Even ImportError
+    pass
Index: type12uni.py
===================================================================
--- type12uni.py	(revision 0)
+++ type12uni.py	(revision 0)
@@ -0,0 +1,1352 @@
+# Automatically generated file.
+# Don't edit this file. Edit _mathtext_manual_data.py instead
+
+type12uni = {r'uni24C8' : 9416,
+r'aring' : 229,
+r'uni22A0' : 8864,
+r'uni2292' : 8850,
+r'quotedblright' : 8221,
+r'uni03D2' : 978,
+r'uni2215' : 8725,
+r'uni03D0' : 976,
+r'V' : 86,
+r'dollar' : 36,
+r'uni301E' : 12318,
+r'uni03D5' : 981,
+r'four' : 52,
+r'uni25A0' : 9632,
+r'uni013C' : 316,
+r'uni013B' : 315,
+r'uni013E' : 318,
+r'Yacute' : 221,
+r'uni25DE' : 9694,
+r'uni013F' : 319,
+r'uni255A' : 9562,
+r'uni2606' : 9734,
+r'uni0180' : 384,
+r'uni22B7' : 8887,
+r'uni044F' : 1103,
+r'uni22B5' : 8885,
+r'uni22B4' : 8884,
+r'uni22AE' : 8878,
+r'uni22B2' : 8882,
+r'uni22B1' : 8881,
+r'uni22B0' : 8880,
+r'uni25CD' : 9677,
+r'uni03CE' : 974,
+r'uni03CD' : 973,
+r'uni03CC' : 972,
+r'uni03CB' : 971,
+r'uni03CA' : 970,
+r'uni22B8' : 8888,
+r'uni22C9' : 8905,
+r'uni0449' : 1097,
+r'uni20DD' : 8413,
+r'uni20DC' : 8412,
+r'uni20DB' : 8411,
+r'uni2231' : 8753,
+r'uni25CF' : 9679,
+r'uni306E' : 12398,
+r'uni03D1' : 977,
+r'uni01A1' : 417,
+r'uni20D7' : 8407,
+r'uni03D6' : 982,
+r'uni2233' : 8755,
+r'uni20D2' : 8402,
+r'uni20D1' : 8401,
+r'uni20D0' : 8400,
+r'P' : 80,
+r'uni22BE' : 8894,
+r'uni22BD' : 8893,
+r'uni22BC' : 8892,
+r'uni22BB' : 8891,
+r'underscore' : 95,
+r'uni03C8' : 968,
+r'uni03C7' : 967,
+r'uni0328' : 808,
+r'uni03C5' : 965,
+r'uni03C4' : 964,
+r'uni03C3' : 963,
+r'uni03C2' : 962,
+r'uni03C1' : 961,
+r'uni03C0' : 960,
+r'uni2010' : 8208,
+r'uni0130' : 304,
+r'uni0133' : 307,
+r'uni0132' : 306,
+r'uni0135' : 309,
+r'uni0134' : 308,
+r'uni0137' : 311,
+r'uni0136' : 310,
+r'uni0139' : 313,
+r'uni0138' : 312,
+r'uni2244' : 8772,
+r'uni229A' : 8858,
+r'uni2571' : 9585,
+r'uni0278' : 632,
+r'uni2239' : 8761,
+r'p' : 112,
+r'uni3019' : 12313,
+r'uni25CB' : 9675,
+r'uni03DB' : 987,
+r'uni03DC' : 988,
+r'uni03DA' : 986,
+r'uni03DF' : 991,
+r'uni03DD' : 989,
+r'uni013D' : 317,
+r'uni220A' : 8714,
+r'uni220C' : 8716,
+r'uni220B' : 8715,
+r'uni220E' : 8718,
+r'uni220D' : 8717,
+r'uni220F' : 8719,
+r'uni22CC' : 8908,
+r'Otilde' : 213,
+r'uni25E5' : 9701,
+r'uni2736' : 10038,
+r'perthousand' : 8240,
+r'zero' : 48,
+r'uni279B' : 10139,
+r'dotlessi' : 305,
+r'uni2279' : 8825,
+r'Scaron' : 352,
+r'zcaron' : 382,
+r'uni21D8' : 8664,
+r'egrave' : 232,
+r'uni0271' : 625,
+r'uni01AA' : 426,
+r'uni2332' : 9010,
+r'section' : 167,
+r'uni25E4' : 9700,
+r'Icircumflex' : 206,
+r'ntilde' : 241,
+r'uni041E' : 1054,
+r'ampersand' : 38,
+r'uni041C' : 1052,
+r'uni041A' : 1050,
+r'uni22AB' : 8875,
+r'uni21DB' : 8667,
+r'dotaccent' : 729,
+r'uni0416' : 1046,
+r'uni0417' : 1047,
+r'uni0414' : 1044,
+r'uni0415' : 1045,
+r'uni0412' : 1042,
+r'uni0413' : 1043,
+r'degree' : 176,
+r'uni0411' : 1041,
+r'K' : 75,
+r'uni25EB' : 9707,
+r'uni25EF' : 9711,
+r'uni0418' : 1048,
+r'uni0419' : 1049,
+r'uni2263' : 8803,
+r'uni226E' : 8814,
+r'uni2251' : 8785,
+r'uni02C8' : 712,
+r'uni2262' : 8802,
+r'acircumflex' : 226,
+r'uni22B3' : 8883,
+r'uni2261' : 8801,
+r'uni2394' : 9108,
+r'Aring' : 197,
+r'uni2260' : 8800,
+r'uni2254' : 8788,
+r'uni0436' : 1078,
+r'uni2267' : 8807,
+r'k' : 107,
+r'uni22C8' : 8904,
+r'uni226A' : 8810,
+r'uni231F' : 8991,
+r'smalltilde' : 732,
+r'uni2201' : 8705,
+r'uni2200' : 8704,
+r'uni2203' : 8707,
+r'uni02BD' : 701,
+r'uni2205' : 8709,
+r'uni2204' : 8708,
+r'Agrave' : 192,
+r'uni2206' : 8710,
+r'uni2209' : 8713,
+r'uni2208' : 8712,
+r'uni226D' : 8813,
+r'uni2264' : 8804,
+r'uni263D' : 9789,
+r'uni2258' : 8792,
+r'uni02D3' : 723,
+r'uni02D2' : 722,
+r'uni02D1' : 721,
+r'uni02D0' : 720,
+r'uni25E1' : 9697,
+r'divide' : 247,
+r'uni02D5' : 725,
+r'uni02D4' : 724,
+r'ocircumflex' : 244,
+r'uni2524' : 9508,
+r'uni043A' : 1082,
+r'uni24CC' : 9420,
+r'asciitilde' : 126,
+r'uni22B9' : 8889,
+r'uni24D2' : 9426,
+r'uni211E' : 8478,
+r'uni211D' : 8477,
+r'uni24DD' : 9437,
+r'uni211A' : 8474,
+r'uni211C' : 8476,
+r'uni211B' : 8475,
+r'uni25C6' : 9670,
+r'uni017F' : 383,
+r'uni017A' : 378,
+r'uni017C' : 380,
+r'uni017B' : 379,
+r'uni0346' : 838,
+r'uni22F1' : 8945,
+r'uni22F0' : 8944,
+r'two' : 50,
+r'uni2298' : 8856,
+r'uni24D1' : 9425,
+r'E' : 69,
+r'uni025D' : 605,
+r'scaron' : 353,
+r'uni2322' : 8994,
+r'uni25E3' : 9699,
+r'uni22BF' : 8895,
+r'F' : 70,
+r'uni0440' : 1088,
+r'uni255E' : 9566,
+r'uni22BA' : 8890,
+r'uni0175' : 373,
+r'uni0174' : 372,
+r'uni0177' : 375,
+r'uni0176' : 374,
+r'bracketleft' : 91,
+r'uni0170' : 368,
+r'uni0173' : 371,
+r'uni0172' : 370,
+r'asciicircum' : 94,
+r'uni0179' : 377,
+r'uni2590' : 9616,
+r'uni25E2' : 9698,
+r'uni2119' : 8473,
+r'uni2118' : 8472,
+r'uni25CC' : 9676,
+r'f' : 102,
+r'ordmasculine' : 186,
+r'uni229B' : 8859,
+r'uni22A1' : 8865,
+r'uni2111' : 8465,
+r'uni2110' : 8464,
+r'uni2113' : 8467,
+r'uni2112' : 8466,
+r'mu' : 181,
+r'uni2281' : 8833,
+r'paragraph' : 182,
+r'nine' : 57,
+r'uni25EC' : 9708,
+r'v' : 118,
+r'uni040C' : 1036,
+r'uni0113' : 275,
+r'uni22D0' : 8912,
+r'uni21CC' : 8652,
+r'uni21CB' : 8651,
+r'uni21CA' : 8650,
+r'uni22A5' : 8869,
+r'uni21CF' : 8655,
+r'uni21CE' : 8654,
+r'uni21CD' : 8653,
+r'guilsinglleft' : 8249,
+r'backslash' : 92,
+r'uni2284' : 8836,
+r'uni224E' : 8782,
+r'uni224D' : 8781,
+r'uni224F' : 8783,
+r'uni224A' : 8778,
+r'uni2287' : 8839,
+r'uni224C' : 8780,
+r'uni224B' : 8779,
+r'uni21BD' : 8637,
+r'uni2286' : 8838,
+r'uni030F' : 783,
+r'uni030D' : 781,
+r'uni030E' : 782,
+r'uni030B' : 779,
+r'uni030C' : 780,
+r'uni030A' : 778,
+r'uni026E' : 622,
+r'uni026D' : 621,
+r'six' : 54,
+r'uni026A' : 618,
+r'uni026C' : 620,
+r'uni25C1' : 9665,
+r'uni20D6' : 8406,
+r'uni045B' : 1115,
+r'uni045C' : 1116,
+r'uni256B' : 9579,
+r'uni045A' : 1114,
+r'uni045F' : 1119,
+r'uni045E' : 1118,
+r'A' : 65,
+r'uni2569' : 9577,
+r'uni0458' : 1112,
+r'uni0459' : 1113,
+r'uni0452' : 1106,
+r'uni0453' : 1107,
+r'uni2562' : 9570,
+r'uni0451' : 1105,
+r'uni0456' : 1110,
+r'uni0457' : 1111,
+r'uni0454' : 1108,
+r'uni0455' : 1109,
+r'icircumflex' : 238,
+r'uni0307' : 775,
+r'uni0304' : 772,
+r'uni0305' : 773,
+r'uni0269' : 617,
+r'uni0268' : 616,
+r'uni0300' : 768,
+r'uni0301' : 769,
+r'uni0265' : 613,
+r'uni0264' : 612,
+r'uni0267' : 615,
+r'uni0266' : 614,
+r'uni0261' : 609,
+r'uni0260' : 608,
+r'uni0263' : 611,
+r'uni0262' : 610,
+r'a' : 97,
+r'uni2207' : 8711,
+r'uni2247' : 8775,
+r'uni2246' : 8774,
+r'uni2241' : 8769,
+r'uni2240' : 8768,
+r'uni2243' : 8771,
+r'uni2242' : 8770,
+r'uni2312' : 8978,
+r'ogonek' : 731,
+r'uni2249' : 8777,
+r'uni2248' : 8776,
+r'uni3030' : 12336,
+r'q' : 113,
+r'uni21C2' : 8642,
+r'uni21C1' : 8641,
+r'uni21C0' : 8640,
+r'uni21C7' : 8647,
+r'uni21C6' : 8646,
+r'uni21C5' : 8645,
+r'uni21C4' : 8644,
+r'uni225F' : 8799,
+r'uni212C' : 8492,
+r'uni21C8' : 8648,
+r'uni2467' : 9319,
+r'oacute' : 243,
+r'uni028F' : 655,
+r'uni028E' : 654,
+r'uni026F' : 623,
+r'uni028C' : 652,
+r'uni028B' : 651,
+r'uni028A' : 650,
+r'uni2510' : 9488,
+r'ograve' : 242,
+r'edieresis' : 235,
+r'uni22CE' : 8910,
+r'uni22CF' : 8911,
+r'uni219F' : 8607,
+r'comma' : 44,
+r'uni22CA' : 8906,
+r'uni0429' : 1065,
+r'uni03C6' : 966,
+r'uni0427' : 1063,
+r'uni0426' : 1062,
+r'uni0425' : 1061,
+r'uni0424' : 1060,
+r'uni0423' : 1059,
+r'uni0422' : 1058,
+r'uni0421' : 1057,
+r'uni0420' : 1056,
+r'uni2465' : 9317,
+r'uni24D0' : 9424,
+r'uni2464' : 9316,
+r'uni0430' : 1072,
+r'otilde' : 245,
+r'uni2661' : 9825,
+r'uni24D6' : 9430,
+r'uni2466' : 9318,
+r'uni24D5' : 9429,
+r'uni219A' : 8602,
+r'uni2518' : 9496,
+r'uni22B6' : 8886,
+r'uni2461' : 9313,
+r'uni24D4' : 9428,
+r'uni2460' : 9312,
+r'uni24EA' : 9450,
+r'guillemotright' : 187,
+r'ecircumflex' : 234,
+r'greater' : 62,
+r'uni2011' : 8209,
+r'uacute' : 250,
+r'uni2462' : 9314,
+r'L' : 76,
+r'bullet' : 8226,
+r'uni02A4' : 676,
+r'uni02A7' : 679,
+r'cedilla' : 184,
+r'uni02A2' : 674,
+r'uni2015' : 8213,
+r'uni22C4' : 8900,
+r'uni22C5' : 8901,
+r'uni22AD' : 8877,
+r'uni22C7' : 8903,
+r'uni22C0' : 8896,
+r'uni2016' : 8214,
+r'uni22C2' : 8898,
+r'uni22C3' : 8899,
+r'uni24CF' : 9423,
+r'uni042F' : 1071,
+r'uni042E' : 1070,
+r'uni042D' : 1069,
+r'ydieresis' : 255,
+r'l' : 108,
+r'logicalnot' : 172,
+r'uni24CA' : 9418,
+r'uni0287' : 647,
+r'uni0286' : 646,
+r'uni0285' : 645,
+r'uni0284' : 644,
+r'uni0283' : 643,
+r'uni0282' : 642,
+r'uni0281' : 641,
+r'uni027C' : 636,
+r'uni2664' : 9828,
+r'exclamdown' : 161,
+r'uni25C4' : 9668,
+r'uni0289' : 649,
+r'uni0288' : 648,
+r'uni039A' : 922,
+r'endash' : 8211,
+r'uni2640' : 9792,
+r'uni20E4' : 8420,
+r'uni0473' : 1139,
+r'uni20E1' : 8417,
+r'uni2642' : 9794,
+r'uni03B8' : 952,
+r'uni03B9' : 953,
+r'agrave' : 224,
+r'uni03B4' : 948,
+r'uni03B5' : 949,
+r'uni03B6' : 950,
+r'uni03B7' : 951,
+r'uni03B0' : 944,
+r'uni03B1' : 945,
+r'uni03B2' : 946,
+r'uni03B3' : 947,
+r'uni2555' : 9557,
+r'Adieresis' : 196,
+r'germandbls' : 223,
+r'Odieresis' : 214,
+r'space' : 32,
+r'uni0126' : 294,
+r'uni0127' : 295,
+r'uni0124' : 292,
+r'uni0125' : 293,
+r'uni0122' : 290,
+r'uni0123' : 291,
+r'uni0120' : 288,
+r'uni0121' : 289,
+r'quoteright' : 8217,
+r'uni2560' : 9568,
+r'uni2556' : 9558,
+r'ucircumflex' : 251,
+r'uni2561' : 9569,
+r'uni2551' : 9553,
+r'uni25B2' : 9650,
+r'uni2550' : 9552,
+r'uni2563' : 9571,
+r'uni2553' : 9555,
+r'G' : 71,
+r'uni2564' : 9572,
+r'uni2552' : 9554,
+r'quoteleft' : 8216,
+r'uni2565' : 9573,
+r'uni2572' : 9586,
+r'uni2568' : 9576,
+r'uni2566' : 9574,
+r'W' : 87,
+r'uni214A' : 8522,
+r'uni012F' : 303,
+r'uni012D' : 301,
+r'uni012E' : 302,
+r'uni012B' : 299,
+r'uni012C' : 300,
+r'uni255C' : 9564,
+r'uni012A' : 298,
+r'uni2289' : 8841,
+r'Q' : 81,
+r'uni2320' : 8992,
+r'uni2321' : 8993,
+r'g' : 103,
+r'uni03BD' : 957,
+r'uni03BE' : 958,
+r'uni03BF' : 959,
+r'uni2282' : 8834,
+r'uni2285' : 8837,
+r'uni03BA' : 954,
+r'uni03BB' : 955,
+r'uni03BC' : 956,
+r'uni2128' : 8488,
+r'uni25B7' : 9655,
+r'w' : 119,
+r'uni0302' : 770,
+r'uni03DE' : 990,
+r'uni25DA' : 9690,
+r'uni0303' : 771,
+r'uni0463' : 1123,
+r'uni0462' : 1122,
+r'uni3018' : 12312,
+r'uni2514' : 9492,
+r'question' : 63,
+r'uni25B3' : 9651,
+r'uni24E1' : 9441,
+r'one' : 49,
+r'uni200A' : 8202,
+r'uni2278' : 8824,
+r'ring' : 730,
+r'uni0195' : 405,
+r'figuredash' : 8210,
+r'uni22EC' : 8940,
+r'uni0339' : 825,
+r'uni0338' : 824,
+r'uni0337' : 823,
+r'uni0336' : 822,
+r'uni0335' : 821,
+r'uni0333' : 819,
+r'uni0332' : 818,
+r'uni0331' : 817,
+r'uni0330' : 816,
+r'uni01C1' : 449,
+r'uni01C0' : 448,
+r'uni01C3' : 451,
+r'uni01C2' : 450,
+r'uni2353' : 9043,
+r'uni0308' : 776,
+r'uni2218' : 8728,
+r'uni2219' : 8729,
+r'uni2216' : 8726,
+r'uni2217' : 8727,
+r'uni2214' : 8724,
+r'uni0309' : 777,
+r'uni2609' : 9737,
+r'uni2213' : 8723,
+r'uni2210' : 8720,
+r'uni2211' : 8721,
+r'uni2245' : 8773,
+r'B' : 66,
+r'uni25D6' : 9686,
+r'iacute' : 237,
+r'uni02E6' : 742,
+r'uni02E7' : 743,
+r'uni02E8' : 744,
+r'uni02E9' : 745,
+r'uni221D' : 8733,
+r'uni221E' : 8734,
+r'Ydieresis' : 376,
+r'uni221C' : 8732,
+r'uni22D7' : 8919,
+r'uni221A' : 8730,
+r'R' : 82,
+r'uni24DC' : 9436,
+r'uni033F' : 831,
+r'uni033E' : 830,
+r'uni033C' : 828,
+r'uni033B' : 827,
+r'uni033A' : 826,
+r'b' : 98,
+r'uni228A' : 8842,
+r'uni22DB' : 8923,
+r'uni2554' : 9556,
+r'uni046B' : 1131,
+r'uni046A' : 1130,
+r'r' : 114,
+r'uni24DB' : 9435,
+r'Ccedilla' : 199,
+r'minus' : 8722,
+r'uni24DA' : 9434,
+r'uni03F0' : 1008,
+r'uni03F1' : 1009,
+r'uni20AC' : 8364,
+r'uni2276' : 8822,
+r'uni24C0' : 9408,
+r'uni0162' : 354,
+r'uni0163' : 355,
+r'uni011E' : 286,
+r'uni011D' : 285,
+r'uni011C' : 284,
+r'uni011B' : 283,
+r'uni0164' : 356,
+r'uni0165' : 357,
+r'Lslash' : 321,
+r'uni0168' : 360,
+r'uni0169' : 361,
+r'uni25C9' : 9673,
+r'uni02E5' : 741,
+r'uni21C3' : 8643,
+r'uni24C4' : 9412,
+r'uni24E2' : 9442,
+r'uni2277' : 8823,
+r'uni013A' : 314,
+r'uni2102' : 8450,
+r'Uacute' : 218,
+r'uni2317' : 8983,
+r'uni2107' : 8455,
+r'uni221F' : 8735,
+r'yacute' : 253,
+r'uni3012' : 12306,
+r'Ucircumflex' : 219,
+r'uni015D' : 349,
+r'quotedbl' : 34,
+r'uni25D9' : 9689,
+r'uni2280' : 8832,
+r'uni22AF' : 8879,
+r'onehalf' : 189,
+r'uni221B' : 8731,
+r'Thorn' : 222,
+r'uni2226' : 8742,
+r'M' : 77,
+r'uni25BA' : 9658,
+r'uni2463' : 9315,
+r'uni2336' : 9014,
+r'eight' : 56,
+r'uni2236' : 8758,
+r'multiply' : 215,
+r'uni210C' : 8460,
+r'uni210A' : 8458,
+r'uni21C9' : 8649,
+r'grave' : 96,
+r'uni210E' : 8462,
+r'uni0117' : 279,
+r'uni016C' : 364,
+r'uni0115' : 277,
+r'uni016A' : 362,
+r'uni016F' : 367,
+r'uni0112' : 274,
+r'uni016D' : 365,
+r'uni016E' : 366,
+r'Ocircumflex' : 212,
+r'uni2305' : 8965,
+r'm' : 109,
+r'uni24DF' : 9439,
+r'uni0119' : 281,
+r'uni0118' : 280,
+r'uni20A3' : 8355,
+r'uni20A4' : 8356,
+r'uni20A7' : 8359,
+r'uni2288' : 8840,
+r'uni24C3' : 9411,
+r'uni251C' : 9500,
+r'uni228D' : 8845,
+r'uni222F' : 8751,
+r'uni222E' : 8750,
+r'uni222D' : 8749,
+r'uni222C' : 8748,
+r'uni222B' : 8747,
+r'uni222A' : 8746,
+r'uni255B' : 9563,
+r'Ugrave' : 217,
+r'uni24DE' : 9438,
+r'guilsinglright' : 8250,
+r'uni250A' : 9482,
+r'Ntilde' : 209,
+r'uni0279' : 633,
+r'questiondown' : 191,
+r'uni256C' : 9580,
+r'Atilde' : 195,
+r'uni0272' : 626,
+r'uni0273' : 627,
+r'uni0270' : 624,
+r'ccedilla' : 231,
+r'uni0276' : 630,
+r'uni0277' : 631,
+r'uni0274' : 628,
+r'uni0275' : 629,
+r'uni2252' : 8786,
+r'uni041F' : 1055,
+r'uni2250' : 8784,
+r'Z' : 90,
+r'uni2256' : 8790,
+r'uni2257' : 8791,
+r'copyright' : 169,
+r'uni2255' : 8789,
+r'uni043D' : 1085,
+r'uni043E' : 1086,
+r'uni043F' : 1087,
+r'yen' : 165,
+r'uni041D' : 1053,
+r'uni043B' : 1083,
+r'uni043C' : 1084,
+r'uni21B0' : 8624,
+r'uni21B1' : 8625,
+r'uni21B2' : 8626,
+r'uni21B3' : 8627,
+r'uni21B4' : 8628,
+r'uni21B5' : 8629,
+r'uni21B6' : 8630,
+r'uni21B7' : 8631,
+r'uni21B8' : 8632,
+r'Eacute' : 201,
+r'uni2311' : 8977,
+r'uni2310' : 8976,
+r'uni228F' : 8847,
+r'uni25DB' : 9691,
+r'uni21BA' : 8634,
+r'uni21BB' : 8635,
+r'uni21BC' : 8636,
+r'uni2017' : 8215,
+r'uni21BE' : 8638,
+r'uni21BF' : 8639,
+r'uni231C' : 8988,
+r'H' : 72,
+r'uni0293' : 659,
+r'uni2202' : 8706,
+r'uni22A4' : 8868,
+r'uni231E' : 8990,
+r'uni2232' : 8754,
+r'uni225B' : 8795,
+r'uni225C' : 8796,
+r'uni24D9' : 9433,
+r'uni225A' : 8794,
+r'uni0438' : 1080,
+r'uni0439' : 1081,
+r'uni225D' : 8797,
+r'uni225E' : 8798,
+r'uni0434' : 1076,
+r'X' : 88,
+r'uni007F' : 127,
+r'uni0437' : 1079,
+r'Idieresis' : 207,
+r'uni0431' : 1073,
+r'uni0432' : 1074,
+r'uni0433' : 1075,
+r'uni22AC' : 8876,
+r'uni22CD' : 8909,
+r'uni25A3' : 9635,
+r'bar' : 124,
+r'uni24BB' : 9403,
+r'uni037E' : 894,
+r'uni027B' : 635,
+r'h' : 104,
+r'uni027A' : 634,
+r'uni027F' : 639,
+r'uni027D' : 637,
+r'uni027E' : 638,
+r'uni2227' : 8743,
+r'uni2004' : 8196,
+r'uni2225' : 8741,
+r'uni2224' : 8740,
+r'uni2223' : 8739,
+r'uni2222' : 8738,
+r'uni2221' : 8737,
+r'uni2220' : 8736,
+r'x' : 120,
+r'uni2323' : 8995,
+r'uni2559' : 9561,
+r'uni2558' : 9560,
+r'uni2229' : 8745,
+r'uni2228' : 8744,
+r'udieresis' : 252,
+r'uni029D' : 669,
+r'ordfeminine' : 170,
+r'uni22CB' : 8907,
+r'uni233D' : 9021,
+r'uni0428' : 1064,
+r'uni24C6' : 9414,
+r'uni22DD' : 8925,
+r'uni24C7' : 9415,
+r'uni015C' : 348,
+r'uni015B' : 347,
+r'uni015A' : 346,
+r'uni22AA' : 8874,
+r'uni015F' : 351,
+r'uni015E' : 350,
+r'braceleft' : 123,
+r'uni24C5' : 9413,
+r'uni0410' : 1040,
+r'uni03AA' : 938,
+r'uni24C2' : 9410,
+r'uni03AC' : 940,
+r'uni03AB' : 939,
+r'macron' : 175,
+r'uni03AD' : 941,
+r'uni03AF' : 943,
+r'uni0294' : 660,
+r'uni0295' : 661,
+r'uni0296' : 662,
+r'uni0297' : 663,
+r'uni0290' : 656,
+r'uni0291' : 657,
+r'uni0292' : 658,
+r'atilde' : 227,
+r'Acircumflex' : 194,
+r'uni2370' : 9072,
+r'uni24C1' : 9409,
+r'uni0298' : 664,
+r'uni0299' : 665,
+r'Oslash' : 216,
+r'uni029E' : 670,
+r'C' : 67,
+r'quotedblleft' : 8220,
+r'uni029B' : 667,
+r'uni029C' : 668,
+r'uni03A9' : 937,
+r'uni03A8' : 936,
+r'S' : 83,
+r'uni24C9' : 9417,
+r'uni03A1' : 929,
+r'uni03A0' : 928,
+r'exclam' : 33,
+r'uni03A5' : 933,
+r'uni03A4' : 932,
+r'uni03A7' : 935,
+r'Zcaron' : 381,
+r'uni2133' : 8499,
+r'uni2132' : 8498,
+r'uni0159' : 345,
+r'uni0158' : 344,
+r'uni2137' : 8503,
+r'uni2005' : 8197,
+r'uni2135' : 8501,
+r'uni2134' : 8500,
+r'uni02BA' : 698,
+r'uni2033' : 8243,
+r'uni0151' : 337,
+r'uni0150' : 336,
+r'uni0157' : 343,
+r'equal' : 61,
+r'uni0155' : 341,
+r'uni0154' : 340,
+r's' : 115,
+r'uni233F' : 9023,
+r'eth' : 240,
+r'uni24BE' : 9406,
+r'uni21E9' : 8681,
+r'uni2060' : 8288,
+r'Egrave' : 200,
+r'uni255D' : 9565,
+r'uni24CD' : 9421,
+r'uni21E1' : 8673,
+r'uni21B9' : 8633,
+r'hyphen' : 45,
+r'uni01BE' : 446,
+r'uni01BB' : 443,
+r'period' : 46,
+r'igrave' : 236,
+r'uni01BA' : 442,
+r'uni2296' : 8854,
+r'uni2297' : 8855,
+r'uni2294' : 8852,
+r'uni2295' : 8853,
+r'colon' : 58,
+r'uni2293' : 8851,
+r'uni2290' : 8848,
+r'uni2291' : 8849,
+r'uni032D' : 813,
+r'uni032E' : 814,
+r'uni032F' : 815,
+r'uni032A' : 810,
+r'uni032B' : 811,
+r'uni032C' : 812,
+r'uni231D' : 8989,
+r'Ecircumflex' : 202,
+r'uni24D7' : 9431,
+r'uni25DD' : 9693,
+r'trademark' : 8482,
+r'Aacute' : 193,
+r'cent' : 162,
+r'uni0445' : 1093,
+r'uni266E' : 9838,
+r'uni266D' : 9837,
+r'uni266B' : 9835,
+r'uni03C9' : 969,
+r'uni2003' : 8195,
+r'uni2047' : 8263,
+r'lslash' : 322,
+r'uni03A6' : 934,
+r'uni2043' : 8259,
+r'uni250C' : 9484,
+r'uni2040' : 8256,
+r'uni255F' : 9567,
+r'uni24CB' : 9419,
+r'uni0472' : 1138,
+r'uni0446' : 1094,
+r'uni0474' : 1140,
+r'uni0475' : 1141,
+r'uni2508' : 9480,
+r'uni2660' : 9824,
+r'uni2506' : 9478,
+r'uni2502' : 9474,
+r'c' : 99,
+r'uni2500' : 9472,
+r'N' : 78,
+r'uni22A6' : 8870,
+r'uni21E7' : 8679,
+r'uni2130' : 8496,
+r'uni2002' : 8194,
+r'breve' : 728,
+r'uni0442' : 1090,
+r'Oacute' : 211,
+r'uni229F' : 8863,
+r'uni25C7' : 9671,
+r'uni229D' : 8861,
+r'uni229E' : 8862,
+r'guillemotleft' : 171,
+r'uni0329' : 809,
+r'uni24E5' : 9445,
+r'uni011F' : 287,
+r'uni0324' : 804,
+r'uni0325' : 805,
+r'uni0326' : 806,
+r'uni0327' : 807,
+r'uni0321' : 801,
+r'uni0322' : 802,
+r'n' : 110,
+r'uni2032' : 8242,
+r'uni2269' : 8809,
+r'uni2268' : 8808,
+r'uni0306' : 774,
+r'uni226B' : 8811,
+r'uni21EA' : 8682,
+r'uni0166' : 358,
+r'uni203B' : 8251,
+r'uni01B5' : 437,
+r'idieresis' : 239,
+r'uni02BC' : 700,
+r'uni01B0' : 432,
+r'braceright' : 125,
+r'seven' : 55,
+r'uni02BB' : 699,
+r'uni011A' : 282,
+r'uni29FB' : 10747,
+r'brokenbar' : 166,
+r'uni2036' : 8246,
+r'uni25C0' : 9664,
+r'uni0156' : 342,
+r'uni22D5' : 8917,
+r'uni0258' : 600,
+r'ugrave' : 249,
+r'uni22D6' : 8918,
+r'uni22D1' : 8913,
+r'uni2034' : 8244,
+r'uni22D3' : 8915,
+r'uni22D2' : 8914,
+r'uni203C' : 8252,
+r'uni223E' : 8766,
+r'uni02BF' : 703,
+r'uni22D9' : 8921,
+r'uni22D8' : 8920,
+r'uni25BD' : 9661,
+r'uni25BE' : 9662,
+r'uni25BF' : 9663,
+r'uni041B' : 1051,
+r'periodcentered' : 183,
+r'uni25BC' : 9660,
+r'uni019E' : 414,
+r'uni019B' : 411,
+r'uni019A' : 410,
+r'uni2007' : 8199,
+r'uni0391' : 913,
+r'uni0390' : 912,
+r'uni0393' : 915,
+r'uni0392' : 914,
+r'uni0395' : 917,
+r'uni0394' : 916,
+r'uni0397' : 919,
+r'uni0396' : 918,
+r'uni0399' : 921,
+r'uni0398' : 920,
+r'uni25C8' : 9672,
+r'uni2468' : 9320,
+r'sterling' : 163,
+r'uni22EB' : 8939,
+r'uni039C' : 924,
+r'uni039B' : 923,
+r'uni039E' : 926,
+r'uni039D' : 925,
+r'uni039F' : 927,
+r'I' : 73,
+r'uni03E1' : 993,
+r'uni03E0' : 992,
+r'uni2319' : 8985,
+r'uni228B' : 8843,
+r'uni25B5' : 9653,
+r'uni25B6' : 9654,
+r'uni22EA' : 8938,
+r'uni24B9' : 9401,
+r'uni044E' : 1102,
+r'uni0199' : 409,
+r'uni2266' : 8806,
+r'Y' : 89,
+r'uni22A2' : 8866,
+r'Eth' : 208,
+r'uni266F' : 9839,
+r'emdash' : 8212,
+r'uni263B' : 9787,
+r'uni24BD' : 9405,
+r'uni22DE' : 8926,
+r'uni0360' : 864,
+r'uni2557' : 9559,
+r'uni22DF' : 8927,
+r'uni22DA' : 8922,
+r'uni22DC' : 8924,
+r'uni0361' : 865,
+r'i' : 105,
+r'uni24BF' : 9407,
+r'uni0362' : 866,
+r'uni263E' : 9790,
+r'uni028D' : 653,
+r'uni2259' : 8793,
+r'uni0323' : 803,
+r'uni2265' : 8805,
+r'daggerdbl' : 8225,
+r'y' : 121,
+r'uni010A' : 266,
+r'plusminus' : 177,
+r'less' : 60,
+r'uni21AE' : 8622,
+r'uni0315' : 789,
+r'uni230B' : 8971,
+r'uni21AF' : 8623,
+r'uni21AA' : 8618,
+r'uni21AC' : 8620,
+r'uni21AB' : 8619,
+r'uni01FB' : 507,
+r'uni01FC' : 508,
+r'uni223A' : 8762,
+r'uni01FA' : 506,
+r'uni01FF' : 511,
+r'uni01FD' : 509,
+r'uni01FE' : 510,
+r'uni2567' : 9575,
+r'uni25E0' : 9696,
+r'uni0104' : 260,
+r'uni0105' : 261,
+r'uni0106' : 262,
+r'uni0107' : 263,
+r'uni0100' : 256,
+r'uni0101' : 257,
+r'uni0102' : 258,
+r'uni0103' : 259,
+r'uni2038' : 8248,
+r'uni2009' : 8201,
+r'uni2008' : 8200,
+r'uni0108' : 264,
+r'uni0109' : 265,
+r'uni02A1' : 673,
+r'uni223B' : 8763,
+r'uni226C' : 8812,
+r'uni25AC' : 9644,
+r'uni24D3' : 9427,
+r'uni21E0' : 8672,
+r'uni21E3' : 8675,
+r'Udieresis' : 220,
+r'uni21E2' : 8674,
+r'D' : 68,
+r'uni21E5' : 8677,
+r'uni2621' : 9761,
+r'uni21D1' : 8657,
+r'uni203E' : 8254,
+r'uni22C6' : 8902,
+r'uni21E4' : 8676,
+r'uni010D' : 269,
+r'uni010E' : 270,
+r'uni010F' : 271,
+r'five' : 53,
+r'T' : 84,
+r'uni010B' : 267,
+r'uni010C' : 268,
+r'uni2605' : 9733,
+r'uni2663' : 9827,
+r'uni21E6' : 8678,
+r'uni24B6' : 9398,
+r'uni22C1' : 8897,
+r'oslash' : 248,
+r'acute' : 180,
+r'uni01F0' : 496,
+r'd' : 100,
+r'OE' : 338,
+r'uni22E3' : 8931,
+r'Igrave' : 204,
+r'uni2308' : 8968,
+r'uni2309' : 8969,
+r'uni21A9' : 8617,
+r't' : 116,
+r'uni2313' : 8979,
+r'uni03A3' : 931,
+r'uni21A4' : 8612,
+r'uni21A7' : 8615,
+r'uni21A6' : 8614,
+r'uni21A1' : 8609,
+r'uni21A0' : 8608,
+r'uni21A3' : 8611,
+r'uni21A2' : 8610,
+r'parenright' : 41,
+r'uni256A' : 9578,
+r'uni25DC' : 9692,
+r'uni24CE' : 9422,
+r'uni042C' : 1068,
+r'uni24E0' : 9440,
+r'uni042B' : 1067,
+r'uni0409' : 1033,
+r'uni0408' : 1032,
+r'uni24E7' : 9447,
+r'uni25B4' : 9652,
+r'uni042A' : 1066,
+r'uni228E' : 8846,
+r'uni0401' : 1025,
+r'adieresis' : 228,
+r'uni0403' : 1027,
+r'quotesingle' : 39,
+r'uni0405' : 1029,
+r'uni0404' : 1028,
+r'uni0407' : 1031,
+r'uni0406' : 1030,
+r'uni229C' : 8860,
+r'uni2306' : 8966,
+r'uni2253' : 8787,
+r'twodotenleader' : 8229,
+r'uni2131' : 8497,
+r'uni21DA' : 8666,
+r'uni2234' : 8756,
+r'uni2235' : 8757,
+r'uni01A5' : 421,
+r'uni2237' : 8759,
+r'uni2230' : 8752,
+r'uni02CC' : 716,
+r'slash' : 47,
+r'uni01A0' : 416,
+r'ellipsis' : 8230,
+r'uni2299' : 8857,
+r'uni2238' : 8760,
+r'numbersign' : 35,
+r'uni21A8' : 8616,
+r'uni223D' : 8765,
+r'uni01AF' : 431,
+r'uni223F' : 8767,
+r'uni01AD' : 429,
+r'uni01AB' : 427,
+r'odieresis' : 246,
+r'uni223C' : 8764,
+r'uni227D' : 8829,
+r'uni0280' : 640,
+r'O' : 79,
+r'uni227E' : 8830,
+r'uni21A5' : 8613,
+r'uni22D4' : 8916,
+r'uni25D4' : 9684,
+r'uni227F' : 8831,
+r'uni0435' : 1077,
+r'uni2302' : 8962,
+r'uni2669' : 9833,
+r'uni24E3' : 9443,
+r'uni2720' : 10016,
+r'uni22A8' : 8872,
+r'uni22A9' : 8873,
+r'uni040A' : 1034,
+r'uni22A7' : 8871,
+r'oe' : 339,
+r'uni040B' : 1035,
+r'uni040E' : 1038,
+r'uni22A3' : 8867,
+r'o' : 111,
+r'uni040F' : 1039,
+r'Edieresis' : 203,
+r'uni25D5' : 9685,
+r'plus' : 43,
+r'uni044D' : 1101,
+r'uni263C' : 9788,
+r'uni22E6' : 8934,
+r'uni2283' : 8835,
+r'uni258C' : 9612,
+r'uni219E' : 8606,
+r'uni24E4' : 9444,
+r'uni2136' : 8502,
+r'dagger' : 8224,
+r'uni24B7' : 9399,
+r'uni219B' : 8603,
+r'uni22E5' : 8933,
+r'three' : 51,
+r'uni210B' : 8459,
+r'uni2534' : 9524,
+r'uni24B8' : 9400,
+r'uni230A' : 8970,
+r'hungarumlaut' : 733,
+r'parenleft' : 40,
+r'uni0148' : 328,
+r'uni0149' : 329,
+r'uni2124' : 8484,
+r'uni2125' : 8485,
+r'uni2126' : 8486,
+r'uni2127' : 8487,
+r'uni0140' : 320,
+r'uni2129' : 8489,
+r'uni25C5' : 9669,
+r'uni0143' : 323,
+r'uni0144' : 324,
+r'uni0145' : 325,
+r'uni0146' : 326,
+r'uni0147' : 327,
+r'uni210D' : 8461,
+r'fraction' : 8260,
+r'uni2031' : 8241,
+r'uni2196' : 8598,
+r'uni2035' : 8245,
+r'uni24E6' : 9446,
+r'uni016B' : 363,
+r'uni24BA' : 9402,
+r'uni266A' : 9834,
+r'uni0116' : 278,
+r'uni2115' : 8469,
+r'registered' : 174,
+r'J' : 74,
+r'uni25DF' : 9695,
+r'uni25CE' : 9678,
+r'uni273D' : 10045,
+r'dieresis' : 168,
+r'uni212B' : 8491,
+r'uni0114' : 276,
+r'uni212D' : 8493,
+r'uni212E' : 8494,
+r'uni212F' : 8495,
+r'uni014A' : 330,
+r'uni014B' : 331,
+r'uni014C' : 332,
+r'uni014D' : 333,
+r'uni014E' : 334,
+r'uni014F' : 335,
+r'uni025E' : 606,
+r'uni24E8' : 9448,
+r'uni0111' : 273,
+r'uni24E9' : 9449,
+r'Ograve' : 210,
+r'j' : 106,
+r'uni2195' : 8597,
+r'uni2194' : 8596,
+r'uni2197' : 8599,
+r'uni2037' : 8247,
+r'uni2191' : 8593,
+r'uni2190' : 8592,
+r'uni2193' : 8595,
+r'uni2192' : 8594,
+r'uni29FA' : 10746,
+r'uni2713' : 10003,
+r'z' : 122,
+r'uni2199' : 8601,
+r'uni2198' : 8600,
+r'uni2667' : 9831,
+r'ae' : 230,
+r'uni0448' : 1096,
+r'semicolon' : 59,
+r'uni2666' : 9830,
+r'uni038F' : 911,
+r'uni0444' : 1092,
+r'uni0447' : 1095,
+r'uni038E' : 910,
+r'uni0441' : 1089,
+r'uni038C' : 908,
+r'uni0443' : 1091,
+r'uni038A' : 906,
+r'uni0250' : 592,
+r'uni0251' : 593,
+r'uni0252' : 594,
+r'uni0253' : 595,
+r'uni0254' : 596,
+r'at' : 64,
+r'uni0256' : 598,
+r'uni0257' : 599,
+r'uni0167' : 359,
+r'uni0259' : 601,
+r'uni228C' : 8844,
+r'uni2662' : 9826,
+r'uni0319' : 793,
+r'uni0318' : 792,
+r'uni24BC' : 9404,
+r'uni0402' : 1026,
+r'uni22EF' : 8943,
+r'Iacute' : 205,
+r'uni22ED' : 8941,
+r'uni22EE' : 8942,
+r'uni0311' : 785,
+r'uni0310' : 784,
+r'uni21E8' : 8680,
+r'uni0312' : 786,
+r'percent' : 37,
+r'uni0317' : 791,
+r'uni0316' : 790,
+r'uni21D6' : 8662,
+r'uni21D7' : 8663,
+r'uni21D4' : 8660,
+r'uni21D5' : 8661,
+r'uni21D2' : 8658,
+r'uni21D3' : 8659,
+r'uni21D0' : 8656,
+r'uni2138' : 8504,
+r'uni2270' : 8816,
+r'uni2271' : 8817,
+r'uni2272' : 8818,
+r'uni2273' : 8819,
+r'uni2274' : 8820,
+r'uni2275' : 8821,
+r'bracketright' : 93,
+r'uni21D9' : 8665,
+r'uni21DF' : 8671,
+r'uni21DD' : 8669,
+r'uni21DE' : 8670,
+r'AE' : 198,
+r'uni03AE' : 942,
+r'uni227A' : 8826,
+r'uni227B' : 8827,
+r'uni227C' : 8828,
+r'asterisk' : 42,
+r'aacute' : 225,
+r'uni226F' : 8815,
+r'uni22E2' : 8930,
+r'uni0386' : 902,
+r'uni22E0' : 8928,
+r'uni22E1' : 8929,
+r'U' : 85,
+r'uni22E7' : 8935,
+r'uni22E4' : 8932,
+r'uni0387' : 903,
+r'uni031A' : 794,
+r'eacute' : 233,
+r'uni22E8' : 8936,
+r'uni22E9' : 8937,
+r'uni24D8' : 9432,
+r'uni025A' : 602,
+r'uni025B' : 603,
+r'uni025C' : 604,
+r'e' : 101,
+r'uni0128' : 296,
+r'uni025F' : 607,
+r'uni2665' : 9829,
+r'thorn' : 254,
+r'uni0129' : 297,
+r'uni253C' : 9532,
+r'uni25D7' : 9687,
+r'u' : 117,
+r'uni0388' : 904,
+r'uni0389' : 905,
+r'uni0255' : 597,
+r'uni0171' : 369,
+r'uni0384' : 900,
+r'uni0385' : 901,
+r'uni044A' : 1098,
+r'uni252C' : 9516,
+r'uni044C' : 1100,
+r'uni044B' : 1099,
+
+}
+try:
+    from _mathtext_manual_data import _type12uni
+    type12uni.update(_type12uni)
+except (TypeError, SyntaxError): # Just these exceptions should be raised
+    raise
+except: # All other exceptions should be silent. Even ImportError
+    pass
Index: uni2tex.py
===================================================================
--- uni2tex.py	(revision 0)
+++ uni2tex.py	(revision 0)
@@ -0,0 +1,487 @@
+# Automatically generated file.
+# Don't edit this file. Edit _mathtext_manual_data.py instead
+
+uni2tex = {8194 : r'\enspace',
+8195 : r'\quad',
+8197 : r'\thickspace',
+8201 : r'\thinspace',
+8202 : r'\hspace',
+8211 : r'\endash',
+8212 : r'\emdash',
+8214 : r'\Vert',
+8216 : r'\lq',
+8217 : r'\rq',
+8220 : r'\textquotedblleft',
+8221 : r'\textquotedblright',
+8224 : r'\dagger',
+8225 : r'\ddagger',
+8230 : r'\dots',
+8242 : r'\prime',
+8245 : r'\backprime',
+58 : r'\colon',
+60 : r'\less',
+62 : r'\greater',
+91 : r'\lbrack',
+92 : r'\backslash',
+93 : r'\rbrack',
+94 : r'\textasciicircum',
+96 : r'\textasciigrave',
+8892 : r'\barwedge',
+123 : r'\lbrace',
+124 : r'\vert',
+125 : r'\rbrace',
+126 : r'\textasciitilde',
+161 : r'\textexclamdown',
+163 : r'\sterling',
+165 : r'\yen',
+167 : r'\S',
+169 : r'\copyright',
+172 : r'\neg',
+174 : r'\circledR',
+176 : r'\degree',
+177 : r'\pm',
+180 : r'\textasciiacute',
+182 : r'\P',
+183 : r'\cdotp',
+191 : r'\textquestiondown',
+198 : r'\AE',
+8400 : r'\leftharpoonaccent',
+8401 : r'\rightharpoonaccent',
+8406 : r'\overleftarrow',
+215 : r'\times',
+216 : r'\O',
+8411 : r'\dddot',
+8412 : r'\ddddot',
+223 : r'\ss',
+8417 : r'\overleftrightarrow',
+230 : r'\ae',
+240 : r'\eth',
+247 : r'\div',
+248 : r'\o',
+8450 : r'\BbbC',
+8458 : r'\scrg',
+8459 : r'\scrH',
+8464 : r'\scrI',
+8465 : r'\Im',
+8466 : r'\scrL',
+8467 : r'\ell',
+8469 : r'\BbbN',
+8472 : r'\wp',
+8473 : r'\BbbP',
+8474 : r'\BbbQ',
+8475 : r'\scrR',
+8476 : r'\Re',
+8477 : r'\BbbR',
+8484 : r'\BbbZ',
+8487 : r'\mho',
+8488 : r'\frakZ',
+8491 : r'\AA',
+8492 : r'\scrB',
+8493 : r'\frakC',
+8495 : r'\scre',
+8496 : r'\scrE',
+8497 : r'\scrF',
+8498 : r'\Finv',
+8499 : r'\scrM',
+8500 : r'\scro',
+8501 : r'\aleph',
+8502 : r'\beth',
+8503 : r'\gimel',
+8504 : r'\daleth',
+321 : r'\L',
+322 : r'\l',
+338 : r'\OE',
+339 : r'\oe',
+8592 : r'\leftarrow',
+8593 : r'\uparrow',
+8594 : r'\rightarrow',
+8595 : r'\downarrow',
+8596 : r'\leftrightarrow',
+8597 : r'\updownarrow',
+8598 : r'\nwarrow',
+8599 : r'\nearrow',
+8600 : r'\searrow',
+8601 : r'\swarrow',
+8602 : r'\nleftarrow',
+8603 : r'\nrightarrow',
+8606 : r'\twoheadleftarrow',
+8607 : r'\twoheaduparrow',
+8608 : r'\twoheadrightarrow',
+8609 : r'\twoheaddownarrow',
+8610 : r'\leftarrowtail',
+8611 : r'\rightarrowtail',
+8612 : r'\mapsfrom',
+8613 : r'\mapsup',
+8614 : r'\mapsto',
+8615 : r'\mapsdown',
+8616 : r'\updownarrowbar',
+8617 : r'\hookleftarrow',
+8618 : r'\hookrightarrow',
+8619 : r'\looparrowleft',
+8620 : r'\looparrowright',
+8622 : r'\nleftrightarrow',
+8623 : r'\downzigzagarrow',
+8624 : r'\Lsh',
+8625 : r'\Rsh',
+8626 : r'\Ldsh',
+8627 : r'\Rdsh',
+8629 : r'\carriagereturn',
+8630 : r'\curvearrowleft',
+8631 : r'\curvearrowright',
+8634 : r'\acwopencirclearrow',
+8635 : r'\cwopencirclearrow',
+8636 : r'\leftharpoonup',
+8637 : r'\leftharpoondown',
+8638 : r'\upharpoonright',
+8639 : r'\upharpoonleft',
+8640 : r'\rightharpoonup',
+8641 : r'\rightharpoondown',
+8642 : r'\downharpoonright',
+8643 : r'\downharpoonleft',
+8644 : r'\rightleftarrows',
+8645 : r'\updownarrows',
+8646 : r'\leftrightarrows',
+8647 : r'\leftleftarrows',
+8648 : r'\upuparrows',
+8649 : r'\rightrightarrows',
+8650 : r'\downdownarrows',
+8651 : r'\leftrightharpoons',
+8652 : r'\rightleftharpoons',
+8653 : r'\nLeftarrow',
+8654 : r'\nLeftrightarrow',
+8655 : r'\nRightarrow',
+8656 : r'\Leftarrow',
+8657 : r'\Uparrow',
+8658 : r'\Rightarrow',
+8659 : r'\Downarrow',
+8660 : r'\Leftrightarrow',
+8661 : r'\Updownarrow',
+8662 : r'\Nwarrow',
+8663 : r'\Nearrow',
+8664 : r'\Searrow',
+8665 : r'\Swarrow',
+8666 : r'\Lleftarrow',
+8667 : r'\Rrightarrow',
+8669 : r'\rightzigzagarrow',
+8676 : r'\barleftarrow',
+8677 : r'\rightarrowbar',
+8704 : r'\forall',
+8705 : r'\complement',
+8706 : r'\partial',
+8707 : r'\exists',
+8708 : r'\nexists',
+8709 : r'\varnothing',
+8711 : r'\nabla',
+8712 : r'\in',
+8713 : r'\notin',
+8715 : r'\ni',
+8719 : r'\prod',
+8720 : r'\coprod',
+8721 : r'\sum',
+8722 : r'\minus',
+8723 : r'\mp',
+8724 : r'\dotplus',
+8725 : r'\slash',
+8726 : r'\smallsetminus',
+8727 : r'\ast',
+8728 : r'\circ',
+8729 : r'\bullet',
+8730 : r'\sqrt',
+8733 : r'\propto',
+8734 : r'\infty',
+8736 : r'\angle',
+8737 : r'\measuredangle',
+8738 : r'\sphericalangle',
+8739 : r'\mid',
+8740 : r'\nmid',
+8741 : r'\parallel',
+8742 : r'\nparallel',
+8743 : r'\wedge',
+8744 : r'\vee',
+8745 : r'\cap',
+8746 : r'\cup',
+8747 : r'\int',
+8748 : r'\iint',
+8749 : r'\iiint',
+8750 : r'\oint',
+8751 : r'\oiint',
+8752 : r'\oiiint',
+8968 : r'\lceil',
+8756 : r'\therefore',
+8757 : r'\because',
+8759 : r'\Colon',
+8760 : r'\dotminus',
+8763 : r'\kernelcontraction',
+8764 : r'\sim',
+8765 : r'\backsim',
+8766 : r'\ac',
+8768 : r'\wr',
+8769 : r'\nsim',
+8770 : r'\eqsim',
+8771 : r'\simeq',
+8772 : r'\nsime',
+8773 : r'\cong',
+8775 : r'\ncong',
+8776 : r'\approx',
+8777 : r'\napprox',
+8778 : r'\approxeq',
+8779 : r'\approxident',
+8780 : r'\backcong',
+8781 : r'\asymp',
+8782 : r'\Bumpeq',
+8783 : r'\bumpeq',
+8784 : r'\doteq',
+8785 : r'\Doteq',
+8786 : r'\fallingdotseq',
+8787 : r'\risingdotseq',
+8788 : r'\coloneq',
+8789 : r'\eqcolon',
+8790 : r'\eqcirc',
+8791 : r'\circeq',
+8792 : r'\arceq',
+8793 : r'\wedgeq',
+8794 : r'\veeeq',
+8795 : r'\stareq',
+8796 : r'\triangleq',
+8797 : r'\eqdef',
+8798 : r'\measeq',
+8799 : r'\questeq',
+8800 : r'\ne',
+8801 : r'\equiv',
+8802 : r'\nequiv',
+8803 : r'\Equiv',
+8804 : r'\leq',
+8805 : r'\geq',
+8806 : r'\leqq',
+8807 : r'\geqq',
+8808 : r'\lneqq',
+8809 : r'\gneqq',
+8810 : r'\ll',
+8811 : r'\gg',
+8812 : r'\between',
+8814 : r'\nless',
+8815 : r'\ngtr',
+8816 : r'\nleq',
+8817 : r'\ngeq',
+8818 : r'\lesssim',
+8819 : r'\gtrsim',
+8822 : r'\lessgtr',
+8823 : r'\gtrless',
+8826 : r'\prec',
+8827 : r'\succ',
+8828 : r'\preccurlyeq',
+8829 : r'\succcurlyeq',
+8830 : r'\precsim',
+8831 : r'\succsim',
+8832 : r'\nprec',
+8833 : r'\nsucc',
+8834 : r'\subset',
+8835 : r'\supset',
+8836 : r'\nsubset',
+8837 : r'\nsupset',
+8838 : r'\subseteq',
+8839 : r'\supseteq',
+8840 : r'\nsubseteq',
+8841 : r'\nsupseteq',
+8842 : r'\subsetneq',
+8843 : r'\supsetneq',
+8845 : r'\cupdot',
+8846 : r'\uplus',
+8847 : r'\sqsubset',
+8848 : r'\sqsupset',
+8849 : r'\sqsubseteq',
+8850 : r'\sqsupseteq',
+8851 : r'\sqcap',
+8852 : r'\sqcup',
+8853 : r'\oplus',
+8854 : r'\ominus',
+8855 : r'\otimes',
+8856 : r'\oslash',
+8857 : r'\odot',
+8858 : r'\circledcirc',
+8859 : r'\circledast',
+8861 : r'\circleddash',
+8862 : r'\boxplus',
+8863 : r'\boxminus',
+8864 : r'\boxtimes',
+8865 : r'\boxdot',
+8866 : r'\vdash',
+8867 : r'\dashv',
+8868 : r'\top',
+8869 : r'\bot',
+8871 : r'\models',
+8872 : r'\vDash',
+8873 : r'\Vdash',
+8874 : r'\Vvdash',
+8876 : r'\nvdash',
+8877 : r'\nvDash',
+8878 : r'\nVdash',
+8879 : r'\nVDash',
+8880 : r'\prurel',
+8881 : r'\scurel',
+8882 : r'\vartriangleleft',
+8883 : r'\vartriangleright',
+8884 : r'\trianglelefteq',
+8885 : r'\trianglerighteq',
+8886 : r'\origof',
+8887 : r'\imageof',
+8888 : r'\multimap',
+8890 : r'\intercal',
+8891 : r'\veebar',
+700 : r'\rasp',
+701 : r'\lasp',
+8896 : r'\bigwedge',
+8897 : r'\bigvee',
+8898 : r'\bigcap',
+8899 : r'\bigcup',
+8900 : r'\diamond',
+8901 : r'\cdot',
+8902 : r'\star',
+8903 : r'\divideontimes',
+8904 : r'\bowtie',
+8905 : r'\ltimes',
+8906 : r'\rtimes',
+8907 : r'\leftthreetimes',
+8908 : r'\rightthreetimes',
+8909 : r'\backsimeq',
+8910 : r'\curlyvee',
+8911 : r'\curlywedge',
+8912 : r'\Subset',
+8913 : r'\Supset',
+8914 : r'\Cap',
+8915 : r'\Cup',
+8916 : r'\pitchfork',
+8918 : r'\lessdot',
+8919 : r'\gtrdot',
+8920 : r'\lll',
+8921 : r'\ggg',
+8922 : r'\lesseqgtr',
+8923 : r'\gtreqless',
+8924 : r'\eqless',
+8925 : r'\eqgtr',
+8926 : r'\curlyeqprec',
+8927 : r'\curlyeqsucc',
+8934 : r'\lnsim',
+8935 : r'\gnsim',
+8936 : r'\precnsim',
+8937 : r'\succnsim',
+8938 : r'\ntriangleleft',
+8939 : r'\ntriangleright',
+8940 : r'\ntrianglelefteq',
+8941 : r'\ntrianglerighteq',
+8942 : r'\vdots',
+8943 : r'\cdots',
+8944 : r'\adots',
+8945 : r'\ddots',
+768 : r'\grave',
+769 : r'\acute',
+770 : r'\hat',
+771 : r'\tilde',
+772 : r'\bar',
+774 : r'\breve',
+775 : r'\dot',
+776 : r'\ddot',
+8969 : r'\rceil',
+778 : r'\ocirc',
+779 : r'\H',
+780 : r'\check',
+784 : r'\candra',
+785 : r'\overarc',
+8985 : r'\turnednot',
+8988 : r'\ulcorner',
+8989 : r'\urcorner',
+8990 : r'\llcorner',
+8991 : r'\lrcorner',
+8994 : r'\frown',
+803 : r'\d',
+807 : r'\c',
+808 : r'\k',
+817 : r'\underbar',
+824 : r'\not',
+9021 : r'\obar',
+9023 : r'\solbar',
+865 : r'\t',
+915 : r'\Gamma',
+916 : r'\Delta',
+920 : r'\Theta',
+923 : r'\Lambda',
+926 : r'\Xi',
+928 : r'\Pi',
+931 : r'\Sigma',
+934 : r'\Phi',
+936 : r'\Psi',
+937 : r'\Omega',
+945 : r'\alpha',
+946 : r'\beta',
+947 : r'\gamma',
+948 : r'\delta',
+949 : r'\varepsilon',
+950 : r'\zeta',
+951 : r'\eta',
+952 : r'\theta',
+953 : r'\iota',
+954 : r'\kappa',
+955 : r'\lambda',
+956 : r'\mu',
+957 : r'\nu',
+958 : r'\xi',
+960 : r'\pi',
+961 : r'\rho',
+962 : r'\varsigma',
+963 : r'\sigma',
+964 : r'\tau',
+965 : r'\upsilon',
+966 : r'\varphi',
+967 : r'\chi',
+968 : r'\psi',
+969 : r'\omega',
+978 : r'\Upsilon',
+981 : r'\phi',
+982 : r'\varpi',
+989 : r'\digamma',
+1008 : r'\varkappa',
+1009 : r'\varrho',
+8970 : r'\lfloor',
+8971 : r'\rfloor',
+9416 : r'\circledS',
+8976 : r'\invnot',
+8407 : r'\vec',
+9632 : r'\blacksquare',
+9651 : r'\bigtriangleup',
+9652 : r'\blacktriangle',
+9653 : r'\vartriangle',
+9654 : r'\blacktriangleright',
+9655 : r'\triangleright',
+9661 : r'\bigtriangledown',
+9662 : r'\blacktriangledown',
+9663 : r'\triangledown',
+9664 : r'\blacktriangleleft',
+9665 : r'\triangleleft',
+9675 : r'\bigcirc',
+411 : r'\lambdabar',
+9707 : r'\boxbar',
+9733 : r'\bigstar',
+9761 : r'\danger',
+9824 : r'\spadesuit',
+9825 : r'\heartsuit',
+9826 : r'\diamondsuit',
+9827 : r'\clubsuit',
+9828 : r'\spadesuitopen',
+9831 : r'\clubsuitopen',
+9837 : r'\flat',
+9838 : r'\natural',
+9839 : r'\sharp',
+10003 : r'\checkmark',
+10016 : r'\maltese',
+305 : r'\i',
+8995 : r'\smile',
+8966 : r'\doublebarwedge ?',
+
+}
+try:
+    from _mathtext_manual_data import _uni2tex
+    uni2tex.update(_uni2tex)
+except (TypeError, SyntaxError): # Just these exceptions should be raised
+    raise
+except: # All other exceptions should be silent. Even ImportError
+    pass
Index: uni2type1.py
===================================================================
--- uni2type1.py	(revision 0)
+++ uni2type1.py	(revision 0)
@@ -0,0 +1,1352 @@
+# Automatically generated file.
+# Don't edit this file. Edit _mathtext_manual_data.py instead
+
+uni2type1 = {8194 : r'uni2002',
+8195 : r'uni2003',
+8196 : r'uni2004',
+8197 : r'uni2005',
+8199 : r'uni2007',
+8200 : r'uni2008',
+8201 : r'uni2009',
+8202 : r'uni200A',
+9559 : r'uni2557',
+8252 : r'uni203C',
+8208 : r'uni2010',
+8209 : r'uni2011',
+8210 : r'figuredash',
+8211 : r'endash',
+8212 : r'emdash',
+8213 : r'uni2015',
+8214 : r'uni2016',
+8215 : r'uni2017',
+8216 : r'quoteleft',
+8217 : r'quoteright',
+8220 : r'quotedblleft',
+8221 : r'quotedblright',
+12318 : r'uni301E',
+32 : r'space',
+33 : r'exclam',
+34 : r'quotedbl',
+35 : r'numbersign',
+36 : r'dollar',
+37 : r'percent',
+38 : r'ampersand',
+39 : r'quotesingle',
+40 : r'parenleft',
+41 : r'parenright',
+42 : r'asterisk',
+43 : r'plus',
+44 : r'comma',
+45 : r'hyphen',
+46 : r'period',
+47 : r'slash',
+48 : r'zero',
+49 : r'one',
+50 : r'two',
+51 : r'three',
+52 : r'four',
+53 : r'five',
+54 : r'six',
+55 : r'seven',
+56 : r'eight',
+57 : r'nine',
+58 : r'colon',
+59 : r'semicolon',
+60 : r'less',
+61 : r'equal',
+62 : r'greater',
+63 : r'question',
+64 : r'at',
+65 : r'A',
+66 : r'B',
+67 : r'C',
+68 : r'D',
+69 : r'E',
+70 : r'F',
+71 : r'G',
+72 : r'H',
+73 : r'I',
+74 : r'J',
+75 : r'K',
+76 : r'L',
+77 : r'M',
+78 : r'N',
+79 : r'O',
+80 : r'P',
+81 : r'Q',
+82 : r'R',
+83 : r'S',
+84 : r'T',
+85 : r'U',
+86 : r'V',
+87 : r'W',
+88 : r'X',
+89 : r'Y',
+90 : r'Z',
+91 : r'bracketleft',
+92 : r'backslash',
+93 : r'bracketright',
+94 : r'asciicircum',
+95 : r'underscore',
+96 : r'grave',
+97 : r'a',
+98 : r'b',
+99 : r'c',
+100 : r'd',
+101 : r'e',
+102 : r'f',
+103 : r'g',
+104 : r'h',
+105 : r'i',
+106 : r'j',
+107 : r'k',
+108 : r'l',
+109 : r'm',
+110 : r'n',
+111 : r'o',
+112 : r'p',
+113 : r'q',
+114 : r'r',
+115 : r's',
+116 : r't',
+117 : r'u',
+118 : r'v',
+119 : r'w',
+120 : r'x',
+121 : r'y',
+122 : r'z',
+123 : r'braceleft',
+124 : r'bar',
+125 : r'braceright',
+126 : r'asciitilde',
+127 : r'uni007F',
+9579 : r'uni256B',
+8597 : r'uni2195',
+12312 : r'uni3018',
+12313 : r'uni3019',
+161 : r'exclamdown',
+162 : r'cent',
+163 : r'sterling',
+8356 : r'uni20A4',
+165 : r'yen',
+166 : r'brokenbar',
+167 : r'section',
+168 : r'dieresis',
+169 : r'copyright',
+170 : r'ordfeminine',
+171 : r'guillemotleft',
+172 : r'logicalnot',
+174 : r'registered',
+175 : r'macron',
+176 : r'degree',
+177 : r'plusminus',
+180 : r'acute',
+181 : r'mu',
+182 : r'paragraph',
+183 : r'periodcentered',
+184 : r'cedilla',
+186 : r'ordmasculine',
+187 : r'guillemotright',
+189 : r'onehalf',
+191 : r'questiondown',
+192 : r'Agrave',
+193 : r'Aacute',
+194 : r'Acircumflex',
+195 : r'Atilde',
+196 : r'Adieresis',
+197 : r'Aring',
+198 : r'AE',
+199 : r'Ccedilla',
+200 : r'Egrave',
+201 : r'Eacute',
+202 : r'Ecircumflex',
+203 : r'Edieresis',
+204 : r'Igrave',
+205 : r'Iacute',
+206 : r'Icircumflex',
+207 : r'Idieresis',
+208 : r'Eth',
+209 : r'Ntilde',
+210 : r'Ograve',
+211 : r'Oacute',
+212 : r'Ocircumflex',
+213 : r'Otilde',
+214 : r'Odieresis',
+215 : r'multiply',
+216 : r'Oslash',
+217 : r'Ugrave',
+218 : r'Uacute',
+219 : r'Ucircumflex',
+220 : r'Udieresis',
+221 : r'Yacute',
+222 : r'Thorn',
+223 : r'germandbls',
+224 : r'agrave',
+225 : r'aacute',
+226 : r'acircumflex',
+227 : r'atilde',
+228 : r'adieresis',
+229 : r'aring',
+230 : r'ae',
+231 : r'ccedilla',
+232 : r'egrave',
+233 : r'eacute',
+234 : r'ecircumflex',
+235 : r'edieresis',
+236 : r'igrave',
+237 : r'iacute',
+238 : r'icircumflex',
+239 : r'idieresis',
+240 : r'eth',
+241 : r'ntilde',
+242 : r'ograve',
+243 : r'oacute',
+244 : r'ocircumflex',
+245 : r'otilde',
+246 : r'odieresis',
+247 : r'divide',
+248 : r'oslash',
+249 : r'ugrave',
+250 : r'uacute',
+251 : r'ucircumflex',
+252 : r'udieresis',
+253 : r'yacute',
+254 : r'thorn',
+255 : r'ydieresis',
+256 : r'uni0100',
+257 : r'uni0101',
+258 : r'uni0102',
+259 : r'uni0103',
+260 : r'uni0104',
+261 : r'uni0105',
+262 : r'uni0106',
+263 : r'uni0107',
+264 : r'uni0108',
+265 : r'uni0109',
+266 : r'uni010A',
+267 : r'uni010B',
+268 : r'uni010C',
+269 : r'uni010D',
+270 : r'uni010E',
+271 : r'uni010F',
+8464 : r'uni2110',
+273 : r'uni0111',
+274 : r'uni0112',
+275 : r'uni0113',
+276 : r'uni0114',
+277 : r'uni0115',
+278 : r'uni0116',
+279 : r'uni0117',
+280 : r'uni0118',
+281 : r'uni0119',
+282 : r'uni011A',
+283 : r'uni011B',
+284 : r'uni011C',
+285 : r'uni011D',
+286 : r'uni011E',
+287 : r'uni011F',
+288 : r'uni0120',
+289 : r'uni0121',
+290 : r'uni0122',
+291 : r'uni0123',
+292 : r'uni0124',
+293 : r'uni0125',
+294 : r'uni0126',
+295 : r'uni0127',
+296 : r'uni0128',
+297 : r'uni0129',
+298 : r'uni012A',
+299 : r'uni012B',
+300 : r'uni012C',
+301 : r'uni012D',
+302 : r'uni012E',
+303 : r'uni012F',
+304 : r'uni0130',
+305 : r'dotlessi',
+306 : r'uni0132',
+307 : r'uni0133',
+308 : r'uni0134',
+309 : r'uni0135',
+310 : r'uni0136',
+311 : r'uni0137',
+312 : r'uni0138',
+313 : r'uni0139',
+314 : r'uni013A',
+315 : r'uni013B',
+316 : r'uni013C',
+317 : r'uni013D',
+318 : r'uni013E',
+319 : r'uni013F',
+320 : r'uni0140',
+321 : r'Lslash',
+322 : r'lslash',
+323 : r'uni0143',
+324 : r'uni0144',
+325 : r'uni0145',
+326 : r'uni0146',
+327 : r'uni0147',
+328 : r'uni0148',
+329 : r'uni0149',
+330 : r'uni014A',
+331 : r'uni014B',
+332 : r'uni014C',
+333 : r'uni014D',
+334 : r'uni014E',
+335 : r'uni014F',
+336 : r'uni0150',
+337 : r'uni0151',
+338 : r'OE',
+339 : r'oe',
+340 : r'uni0154',
+341 : r'uni0155',
+342 : r'uni0156',
+343 : r'uni0157',
+344 : r'uni0158',
+345 : r'uni0159',
+346 : r'uni015A',
+347 : r'uni015B',
+348 : r'uni015C',
+349 : r'uni015D',
+350 : r'uni015E',
+351 : r'uni015F',
+352 : r'Scaron',
+353 : r'scaron',
+354 : r'uni0162',
+355 : r'uni0163',
+356 : r'uni0164',
+357 : r'uni0165',
+358 : r'uni0166',
+359 : r'uni0167',
+360 : r'uni0168',
+361 : r'uni0169',
+362 : r'uni016A',
+363 : r'uni016B',
+364 : r'uni016C',
+365 : r'uni016D',
+366 : r'uni016E',
+367 : r'uni016F',
+368 : r'uni0170',
+369 : r'uni0171',
+370 : r'uni0172',
+371 : r'uni0173',
+372 : r'uni0174',
+373 : r'uni0175',
+374 : r'uni0176',
+375 : r'uni0177',
+376 : r'Ydieresis',
+377 : r'uni0179',
+378 : r'uni017A',
+379 : r'uni017B',
+380 : r'uni017C',
+381 : r'Zcaron',
+382 : r'zcaron',
+383 : r'uni017F',
+384 : r'uni0180',
+8256 : r'uni2040',
+8595 : r'uni2193',
+8936 : r'uni22E8',
+8941 : r'uni22ED',
+8592 : r'uni2190',
+8593 : r'uni2191',
+8594 : r'uni2192',
+8259 : r'uni2043',
+8596 : r'uni2194',
+405 : r'uni0195',
+8598 : r'uni2196',
+8599 : r'uni2197',
+8600 : r'uni2198',
+409 : r'uni0199',
+410 : r'uni019A',
+411 : r'uni019B',
+8602 : r'uni219A',
+414 : r'uni019E',
+8607 : r'uni219F',
+416 : r'uni01A0',
+417 : r'uni01A1',
+8610 : r'uni21A2',
+8603 : r'uni219B',
+8612 : r'uni21A4',
+421 : r'uni01A5',
+8614 : r'uni21A6',
+8615 : r'uni21A7',
+8616 : r'uni21A8',
+8617 : r'uni21A9',
+426 : r'uni01AA',
+427 : r'uni01AB',
+8620 : r'uni21AC',
+429 : r'uni01AD',
+8622 : r'uni21AE',
+431 : r'uni01AF',
+432 : r'uni01B0',
+8625 : r'uni21B1',
+8626 : r'uni21B2',
+8627 : r'uni21B3',
+8628 : r'uni21B4',
+437 : r'uni01B5',
+8630 : r'uni21B6',
+8631 : r'uni21B7',
+8632 : r'uni21B8',
+8633 : r'uni21B9',
+442 : r'uni01BA',
+443 : r'uni01BB',
+8636 : r'uni21BC',
+8637 : r'uni21BD',
+446 : r'uni01BE',
+8639 : r'uni21BF',
+448 : r'uni01C0',
+449 : r'uni01C1',
+450 : r'uni01C2',
+451 : r'uni01C3',
+8644 : r'uni21C4',
+8645 : r'uni21C5',
+8646 : r'uni21C6',
+8609 : r'uni21A1',
+8648 : r'uni21C8',
+8649 : r'uni21C9',
+8650 : r'uni21CA',
+8651 : r'uni21CB',
+8652 : r'uni21CC',
+8653 : r'uni21CD',
+8654 : r'uni21CE',
+8655 : r'uni21CF',
+8656 : r'uni21D0',
+8657 : r'uni21D1',
+8658 : r'uni21D2',
+8608 : r'uni21A0',
+8660 : r'uni21D4',
+8661 : r'uni21D5',
+8662 : r'uni21D6',
+8663 : r'uni21D7',
+8664 : r'uni21D8',
+8665 : r'uni21D9',
+8666 : r'uni21DA',
+8667 : r'uni21DB',
+8669 : r'uni21DD',
+8670 : r'uni21DE',
+8613 : r'uni21A5',
+8672 : r'uni21E0',
+8673 : r'uni21E1',
+8674 : r'uni21E2',
+8675 : r'uni21E3',
+8676 : r'uni21E4',
+8677 : r'uni21E5',
+8678 : r'uni21E6',
+8679 : r'uni21E7',
+8680 : r'uni21E8',
+8681 : r'uni21E9',
+8682 : r'uni21EA',
+496 : r'uni01F0',
+506 : r'uni01FA',
+507 : r'uni01FB',
+508 : r'uni01FC',
+509 : r'uni01FD',
+510 : r'uni01FE',
+511 : r'uni01FF',
+8704 : r'uni2200',
+8705 : r'uni2201',
+8706 : r'uni2202',
+8619 : r'uni21AB',
+8708 : r'uni2204',
+8709 : r'uni2205',
+8710 : r'uni2206',
+8711 : r'uni2207',
+8712 : r'uni2208',
+8713 : r'uni2209',
+8714 : r'uni220A',
+8715 : r'uni220B',
+8716 : r'uni220C',
+8717 : r'uni220D',
+8718 : r'uni220E',
+8719 : r'uni220F',
+8720 : r'uni2210',
+8721 : r'uni2211',
+8722 : r'minus',
+8723 : r'uni2213',
+8724 : r'uni2214',
+8725 : r'uni2215',
+8726 : r'uni2216',
+8727 : r'uni2217',
+8728 : r'uni2218',
+8729 : r'uni2219',
+8730 : r'uni221A',
+8623 : r'uni21AF',
+8732 : r'uni221C',
+8733 : r'uni221D',
+8734 : r'uni221E',
+8735 : r'uni221F',
+8736 : r'uni2220',
+8624 : r'uni21B0',
+8738 : r'uni2222',
+8739 : r'uni2223',
+8740 : r'uni2224',
+8741 : r'uni2225',
+8742 : r'uni2226',
+8743 : r'uni2227',
+8744 : r'uni2228',
+8745 : r'uni2229',
+8746 : r'uni222A',
+8747 : r'uni222B',
+8748 : r'uni222C',
+8611 : r'uni21A3',
+8750 : r'uni222E',
+8751 : r'uni222F',
+8752 : r'uni2230',
+8753 : r'uni2231',
+8754 : r'uni2232',
+8755 : r'uni2233',
+8756 : r'uni2234',
+8757 : r'uni2235',
+8758 : r'uni2236',
+8759 : r'uni2237',
+8760 : r'uni2238',
+8761 : r'uni2239',
+8762 : r'uni223A',
+8763 : r'uni223B',
+8764 : r'uni223C',
+8765 : r'uni223D',
+8766 : r'uni223E',
+8629 : r'uni21B5',
+8768 : r'uni2240',
+8288 : r'uni2060',
+8770 : r'uni2242',
+8771 : r'uni2243',
+8772 : r'uni2244',
+8773 : r'uni2245',
+8774 : r'uni2246',
+8775 : r'uni2247',
+8776 : r'uni2248',
+8777 : r'uni2249',
+8778 : r'uni224A',
+8779 : r'uni224B',
+8780 : r'uni224C',
+8781 : r'uni224D',
+8782 : r'uni224E',
+8783 : r'uni224F',
+592 : r'uni0250',
+593 : r'uni0251',
+594 : r'uni0252',
+595 : r'uni0253',
+596 : r'uni0254',
+597 : r'uni0255',
+598 : r'uni0256',
+599 : r'uni0257',
+600 : r'uni0258',
+601 : r'uni0259',
+602 : r'uni025A',
+603 : r'uni025B',
+604 : r'uni025C',
+605 : r'uni025D',
+606 : r'uni025E',
+607 : r'uni025F',
+608 : r'uni0260',
+609 : r'uni0261',
+610 : r'uni0262',
+611 : r'uni0263',
+612 : r'uni0264',
+613 : r'uni0265',
+614 : r'uni0266',
+615 : r'uni0267',
+616 : r'uni0268',
+617 : r'uni0269',
+618 : r'uni026A',
+8811 : r'uni226B',
+620 : r'uni026C',
+621 : r'uni026D',
+622 : r'uni026E',
+623 : r'uni026F',
+624 : r'uni0270',
+625 : r'uni0271',
+626 : r'uni0272',
+627 : r'uni0273',
+628 : r'uni0274',
+629 : r'uni0275',
+630 : r'uni0276',
+631 : r'uni0277',
+632 : r'uni0278',
+633 : r'uni0279',
+634 : r'uni027A',
+635 : r'uni027B',
+636 : r'uni027C',
+637 : r'uni027D',
+638 : r'uni027E',
+639 : r'uni027F',
+640 : r'uni0280',
+641 : r'uni0281',
+642 : r'uni0282',
+643 : r'uni0283',
+644 : r'uni0284',
+645 : r'uni0285',
+646 : r'uni0286',
+647 : r'uni0287',
+648 : r'uni0288',
+649 : r'uni0289',
+650 : r'uni028A',
+651 : r'uni028B',
+652 : r'uni028C',
+653 : r'uni028D',
+654 : r'uni028E',
+655 : r'uni028F',
+656 : r'uni0290',
+657 : r'uni0291',
+658 : r'uni0292',
+659 : r'uni0293',
+660 : r'uni0294',
+661 : r'uni0295',
+662 : r'uni0296',
+663 : r'uni0297',
+664 : r'uni0298',
+665 : r'uni0299',
+8858 : r'uni229A',
+667 : r'uni029B',
+668 : r'uni029C',
+669 : r'uni029D',
+670 : r'uni029E',
+8863 : r'uni229F',
+8864 : r'uni22A0',
+673 : r'uni02A1',
+674 : r'uni02A2',
+8867 : r'uni22A3',
+676 : r'uni02A4',
+8869 : r'uni22A5',
+8870 : r'uni22A6',
+679 : r'uni02A7',
+8872 : r'uni22A8',
+8873 : r'uni22A9',
+8874 : r'uni22AA',
+8647 : r'uni21C7',
+8876 : r'uni22AC',
+8817 : r'uni2271',
+8878 : r'uni22AE',
+8879 : r'uni22AF',
+8880 : r'uni22B0',
+8881 : r'uni22B1',
+8882 : r'uni22B2',
+8883 : r'uni22B3',
+8884 : r'uni22B4',
+8885 : r'uni22B5',
+8886 : r'uni22B6',
+8887 : r'uni22B7',
+8888 : r'uni22B8',
+8889 : r'uni22B9',
+698 : r'uni02BA',
+699 : r'uni02BB',
+700 : r'uni02BC',
+701 : r'uni02BD',
+8894 : r'uni22BE',
+703 : r'uni02BF',
+8896 : r'uni22C0',
+8897 : r'uni22C1',
+8898 : r'uni22C2',
+8899 : r'uni22C3',
+8900 : r'uni22C4',
+8901 : r'uni22C5',
+8902 : r'uni22C6',
+8903 : r'uni22C7',
+712 : r'uni02C8',
+8905 : r'uni22C9',
+8906 : r'uni22CA',
+8907 : r'uni22CB',
+716 : r'uni02CC',
+8909 : r'uni22CD',
+8910 : r'uni22CE',
+8911 : r'uni22CF',
+720 : r'uni02D0',
+721 : r'uni02D1',
+722 : r'uni02D2',
+723 : r'uni02D3',
+724 : r'uni02D4',
+725 : r'uni02D5',
+8918 : r'uni22D6',
+8919 : r'uni22D7',
+728 : r'breve',
+729 : r'dotaccent',
+730 : r'ring',
+731 : r'ogonek',
+732 : r'smalltilde',
+733 : r'hungarumlaut',
+8926 : r'uni22DE',
+8927 : r'uni22DF',
+8928 : r'uni22E0',
+8929 : r'uni22E1',
+8930 : r'uni22E2',
+8931 : r'uni22E3',
+8932 : r'uni22E4',
+741 : r'uni02E5',
+742 : r'uni02E6',
+743 : r'uni02E7',
+744 : r'uni02E8',
+745 : r'uni02E9',
+8938 : r'uni22EA',
+8939 : r'uni22EB',
+8940 : r'uni22EC',
+8822 : r'uni2276',
+8942 : r'uni22EE',
+8943 : r'uni22EF',
+8944 : r'uni22F0',
+8945 : r'uni22F1',
+8659 : r'uni21D3',
+8618 : r'uni21AA',
+768 : r'uni0300',
+769 : r'uni0301',
+770 : r'uni0302',
+771 : r'uni0303',
+772 : r'uni0304',
+773 : r'uni0305',
+774 : r'uni0306',
+775 : r'uni0307',
+776 : r'uni0308',
+777 : r'uni0309',
+778 : r'uni030A',
+779 : r'uni030B',
+780 : r'uni030C',
+781 : r'uni030D',
+782 : r'uni030E',
+783 : r'uni030F',
+784 : r'uni0310',
+785 : r'uni0311',
+786 : r'uni0312',
+8979 : r'uni2313',
+789 : r'uni0315',
+790 : r'uni0316',
+791 : r'uni0317',
+792 : r'uni0318',
+793 : r'uni0319',
+794 : r'uni031A',
+8988 : r'uni231C',
+8989 : r'uni231D',
+8990 : r'uni231E',
+8991 : r'uni231F',
+8992 : r'uni2320',
+801 : r'uni0321',
+802 : r'uni0322',
+803 : r'uni0323',
+804 : r'uni0324',
+805 : r'uni0325',
+806 : r'uni0326',
+807 : r'uni0327',
+808 : r'uni0328',
+809 : r'uni0329',
+810 : r'uni032A',
+811 : r'uni032B',
+812 : r'uni032C',
+813 : r'uni032D',
+814 : r'uni032E',
+815 : r'uni032F',
+816 : r'uni0330',
+817 : r'uni0331',
+818 : r'uni0332',
+819 : r'uni0333',
+821 : r'uni0335',
+822 : r'uni0336',
+823 : r'uni0337',
+824 : r'uni0338',
+825 : r'uni0339',
+826 : r'uni033A',
+827 : r'uni033B',
+828 : r'uni033C',
+9021 : r'uni233D',
+830 : r'uni033E',
+831 : r'uni033F',
+8893 : r'uni22BD',
+9014 : r'uni2336',
+838 : r'uni0346',
+9697 : r'uni25E1',
+9043 : r'uni2353',
+9700 : r'uni25E4',
+8962 : r'uni2302',
+864 : r'uni0360',
+865 : r'uni0361',
+866 : r'uni0362',
+8969 : r'uni2309',
+10045 : r'uni273D',
+9072 : r'uni2370',
+9023 : r'uni233F',
+8895 : r'uni22BF',
+894 : r'uni037E',
+8827 : r'uni227B',
+900 : r'uni0384',
+901 : r'uni0385',
+902 : r'uni0386',
+903 : r'uni0387',
+904 : r'uni0388',
+905 : r'uni0389',
+906 : r'uni038A',
+9441 : r'uni24E1',
+908 : r'uni038C',
+910 : r'uni038E',
+911 : r'uni038F',
+912 : r'uni0390',
+913 : r'uni0391',
+914 : r'uni0392',
+915 : r'uni0393',
+916 : r'uni0394',
+917 : r'uni0395',
+918 : r'uni0396',
+919 : r'uni0397',
+920 : r'uni0398',
+921 : r'uni0399',
+922 : r'uni039A',
+923 : r'uni039B',
+924 : r'uni039C',
+925 : r'uni039D',
+926 : r'uni039E',
+927 : r'uni039F',
+928 : r'uni03A0',
+929 : r'uni03A1',
+12306 : r'uni3012',
+931 : r'uni03A3',
+932 : r'uni03A4',
+933 : r'uni03A5',
+934 : r'uni03A6',
+935 : r'uni03A7',
+936 : r'uni03A8',
+937 : r'uni03A9',
+938 : r'uni03AA',
+939 : r'uni03AB',
+940 : r'uni03AC',
+941 : r'uni03AD',
+942 : r'uni03AE',
+943 : r'uni03AF',
+944 : r'uni03B0',
+945 : r'uni03B1',
+946 : r'uni03B2',
+947 : r'uni03B3',
+948 : r'uni03B4',
+949 : r'uni03B5',
+950 : r'uni03B6',
+951 : r'uni03B7',
+952 : r'uni03B8',
+953 : r'uni03B9',
+954 : r'uni03BA',
+955 : r'uni03BB',
+956 : r'uni03BC',
+957 : r'uni03BD',
+958 : r'uni03BE',
+959 : r'uni03BF',
+960 : r'uni03C0',
+961 : r'uni03C1',
+962 : r'uni03C2',
+963 : r'uni03C3',
+964 : r'uni03C4',
+965 : r'uni03C5',
+966 : r'uni03C6',
+967 : r'uni03C7',
+968 : r'uni03C8',
+969 : r'uni03C9',
+970 : r'uni03CA',
+971 : r'uni03CB',
+972 : r'uni03CC',
+973 : r'uni03CD',
+974 : r'uni03CE',
+976 : r'uni03D0',
+977 : r'uni03D1',
+978 : r'uni03D2',
+8355 : r'uni20A3',
+981 : r'uni03D5',
+982 : r'uni03D6',
+986 : r'uni03DA',
+987 : r'uni03DB',
+988 : r'uni03DC',
+989 : r'uni03DD',
+990 : r'uni03DE',
+991 : r'uni03DF',
+992 : r'uni03E0',
+993 : r'uni03E1',
+10747 : r'uni29FB',
+8359 : r'uni20A7',
+1008 : r'uni03F0',
+1009 : r'uni03F1',
+9567 : r'uni255F',
+1025 : r'uni0401',
+1026 : r'uni0402',
+1027 : r'uni0403',
+1028 : r'uni0404',
+1029 : r'uni0405',
+1030 : r'uni0406',
+1031 : r'uni0407',
+1032 : r'uni0408',
+1033 : r'uni0409',
+1034 : r'uni040A',
+1035 : r'uni040B',
+1036 : r'uni040C',
+1038 : r'uni040E',
+1039 : r'uni040F',
+1040 : r'uni0410',
+1041 : r'uni0411',
+1042 : r'uni0412',
+1043 : r'uni0413',
+1044 : r'uni0414',
+1045 : r'uni0415',
+1046 : r'uni0416',
+1047 : r'uni0417',
+1048 : r'uni0418',
+1049 : r'uni0419',
+1050 : r'uni041A',
+1051 : r'uni041B',
+1052 : r'uni041C',
+1053 : r'uni041D',
+1054 : r'uni041E',
+1055 : r'uni041F',
+1056 : r'uni0420',
+1057 : r'uni0421',
+1058 : r'uni0422',
+1059 : r'uni0423',
+1060 : r'uni0424',
+1061 : r'uni0425',
+1062 : r'uni0426',
+1063 : r'uni0427',
+1064 : r'uni0428',
+1065 : r'uni0429',
+1066 : r'uni042A',
+1067 : r'uni042B',
+1068 : r'uni042C',
+1069 : r'uni042D',
+1070 : r'uni042E',
+1071 : r'uni042F',
+1072 : r'uni0430',
+1073 : r'uni0431',
+1074 : r'uni0432',
+1075 : r'uni0433',
+1076 : r'uni0434',
+1077 : r'uni0435',
+1078 : r'uni0436',
+1079 : r'uni0437',
+1080 : r'uni0438',
+1081 : r'uni0439',
+1082 : r'uni043A',
+1083 : r'uni043B',
+1084 : r'uni043C',
+1085 : r'uni043D',
+1086 : r'uni043E',
+1087 : r'uni043F',
+1088 : r'uni0440',
+1089 : r'uni0441',
+1090 : r'uni0442',
+1091 : r'uni0443',
+1092 : r'uni0444',
+1093 : r'uni0445',
+1094 : r'uni0446',
+1095 : r'uni0447',
+1096 : r'uni0448',
+1097 : r'uni0449',
+1098 : r'uni044A',
+1099 : r'uni044B',
+1100 : r'uni044C',
+1101 : r'uni044D',
+1102 : r'uni044E',
+1103 : r'uni044F',
+1105 : r'uni0451',
+1106 : r'uni0452',
+1107 : r'uni0453',
+1108 : r'uni0454',
+1109 : r'uni0455',
+1110 : r'uni0456',
+1111 : r'uni0457',
+1112 : r'uni0458',
+1113 : r'uni0459',
+1114 : r'uni045A',
+1115 : r'uni045B',
+1116 : r'uni045C',
+9789 : r'uni263D',
+1118 : r'uni045E',
+1119 : r'uni045F',
+9312 : r'uni2460',
+9313 : r'uni2461',
+1122 : r'uni0462',
+1123 : r'uni0463',
+9316 : r'uni2464',
+9317 : r'uni2465',
+9318 : r'uni2466',
+9319 : r'uni2467',
+8971 : r'uni230B',
+1130 : r'uni046A',
+1131 : r'uni046B',
+1138 : r'uni0472',
+1139 : r'uni0473',
+1140 : r'uni0474',
+1141 : r'uni0475',
+8767 : r'uni223F',
+9407 : r'uni24BF',
+12398 : r'uni306E',
+8832 : r'uni2280',
+8904 : r'uni22C8',
+9410 : r'uni24C2',
+9837 : r'uni266D',
+9411 : r'uni24C3',
+9413 : r'uni24C5',
+10746 : r'uni29FA',
+8731 : r'uni221B',
+9314 : r'uni2462',
+9415 : r'uni24C7',
+9787 : r'uni263B',
+8837 : r'uni2285',
+9398 : r'uni24B6',
+9399 : r'uni24B7',
+9400 : r'uni24B8',
+9401 : r'uni24B9',
+9402 : r'uni24BA',
+9403 : r'uni24BB',
+9404 : r'uni24BC',
+9405 : r'uni24BD',
+9406 : r'uni24BE',
+8995 : r'uni2323',
+9408 : r'uni24C0',
+9409 : r'uni24C1',
+8965 : r'uni2305',
+9315 : r'uni2463',
+9412 : r'uni24C4',
+8935 : r'uni22E7',
+9414 : r'uni24C6',
+8224 : r'dagger',
+9416 : r'uni24C8',
+9417 : r'uni24C9',
+9418 : r'uni24CA',
+9419 : r'uni24CB',
+9420 : r'uni24CC',
+9421 : r'uni24CD',
+9422 : r'uni24CE',
+9423 : r'uni24CF',
+9424 : r'uni24D0',
+9425 : r'uni24D1',
+8737 : r'uni2221',
+9427 : r'uni24D3',
+9428 : r'uni24D4',
+9429 : r'uni24D5',
+9430 : r'uni24D6',
+9431 : r'uni24D7',
+9432 : r'uni24D8',
+9433 : r'uni24D9',
+9434 : r'uni24DA',
+9435 : r'uni24DB',
+9436 : r'uni24DC',
+9437 : r'uni24DD',
+9438 : r'uni24DE',
+8634 : r'uni21BA',
+9440 : r'uni24E0',
+8400 : r'uni20D0',
+9442 : r'uni24E2',
+9443 : r'uni24E3',
+9444 : r'uni24E4',
+8225 : r'daggerdbl',
+9446 : r'uni24E6',
+8401 : r'uni20D1',
+9448 : r'uni24E8',
+9449 : r'uni24E9',
+9450 : r'uni24EA',
+8402 : r'uni20D2',
+9010 : r'uni2332',
+9692 : r'uni25DC',
+8635 : r'uni21BB',
+8976 : r'uni2310',
+9472 : r'uni2500',
+9474 : r'uni2502',
+8226 : r'bullet',
+8908 : r'uni22CC',
+8406 : r'uni20D6',
+9478 : r'uni2506',
+9480 : r'uni2508',
+8260 : r'fraction',
+9482 : r'uni250A',
+8407 : r'uni20D7',
+9484 : r'uni250C',
+8749 : r'uni222D',
+9488 : r'uni2510',
+9492 : r'uni2514',
+9496 : r'uni2518',
+8983 : r'uni2317',
+8977 : r'uni2311',
+9829 : r'uni2665',
+8411 : r'uni20DB',
+9508 : r'uni2524',
+8937 : r'uni22E9',
+8412 : r'uni20DC',
+9516 : r'uni252C',
+8970 : r'uni230A',
+8413 : r'uni20DD',
+8364 : r'uni20AC',
+9524 : r'uni2534',
+8978 : r'uni2312',
+9439 : r'uni24DF',
+9532 : r'uni253C',
+8842 : r'uni228A',
+8417 : r'uni20E1',
+9552 : r'uni2550',
+9553 : r'uni2551',
+9554 : r'uni2552',
+9555 : r'uni2553',
+9556 : r'uni2554',
+9557 : r'uni2555',
+9558 : r'uni2556',
+8638 : r'uni21BE',
+9560 : r'uni2558',
+8420 : r'uni20E4',
+9562 : r'uni255A',
+9563 : r'uni255B',
+9564 : r'uni255C',
+8229 : r'twodotenleader',
+9566 : r'uni255E',
+9445 : r'uni24E5',
+9568 : r'uni2560',
+9569 : r'uni2561',
+9570 : r'uni2562',
+9571 : r'uni2563',
+9572 : r'uni2564',
+9573 : r'uni2565',
+9574 : r'uni2566',
+9575 : r'uni2567',
+9576 : r'uni2568',
+9577 : r'uni2569',
+9578 : r'uni256A',
+9447 : r'uni24E7',
+9580 : r'uni256C',
+8994 : r'uni2322',
+8707 : r'uni2203',
+9585 : r'uni2571',
+9586 : r'uni2572',
+9662 : r'uni25BE',
+10003 : r'uni2713',
+9108 : r'uni2394',
+8230 : r'ellipsis',
+8912 : r'uni22D0',
+8769 : r'uni2241',
+8968 : r'uni2308',
+9616 : r'uni2590',
+8640 : r'uni21C0',
+8913 : r'uni22D1',
+9733 : r'uni2605',
+9632 : r'uni25A0',
+9635 : r'uni25A3',
+9650 : r'uni25B2',
+9644 : r'uni25AC',
+8641 : r'uni21C1',
+9651 : r'uni25B3',
+9652 : r'uni25B4',
+9653 : r'uni25B5',
+9654 : r'uni25B6',
+9655 : r'uni25B7',
+8914 : r'uni22D2',
+9500 : r'uni251C',
+9658 : r'uni25BA',
+9660 : r'uni25BC',
+9661 : r'uni25BD',
+9565 : r'uni255D',
+9663 : r'uni25BF',
+9664 : r'uni25C0',
+9665 : r'uni25C1',
+8875 : r'uni22AB',
+9668 : r'uni25C4',
+9669 : r'uni25C5',
+9670 : r'uni25C6',
+9671 : r'uni25C7',
+9672 : r'uni25C8',
+9673 : r'uni25C9',
+9675 : r'uni25CB',
+9676 : r'uni25CC',
+9677 : r'uni25CD',
+9678 : r'uni25CE',
+9679 : r'uni25CF',
+8642 : r'uni21C2',
+9684 : r'uni25D4',
+9685 : r'uni25D5',
+8915 : r'uni22D3',
+9687 : r'uni25D7',
+9689 : r'uni25D9',
+9690 : r'uni25DA',
+9691 : r'uni25DB',
+8847 : r'uni228F',
+9693 : r'uni25DD',
+9694 : r'uni25DE',
+9695 : r'uni25DF',
+9696 : r'uni25E0',
+8784 : r'uni2250',
+9698 : r'uni25E2',
+9699 : r'uni25E3',
+9320 : r'uni2468',
+9701 : r'uni25E5',
+8601 : r'uni2199',
+9707 : r'uni25EB',
+9708 : r'uni25EC',
+8786 : r'uni2252',
+8643 : r'uni21C3',
+9711 : r'uni25EF',
+8787 : r'uni2253',
+8916 : r'uni22D4',
+8788 : r'uni2254',
+8789 : r'uni2255',
+8790 : r'uni2256',
+9734 : r'uni2606',
+9737 : r'uni2609',
+8791 : r'uni2257',
+8985 : r'uni2319',
+8450 : r'uni2102',
+8792 : r'uni2258',
+8917 : r'uni22D5',
+8671 : r'uni21DF',
+8934 : r'uni22E6',
+8794 : r'uni225A',
+9761 : r'uni2621',
+8795 : r'uni225B',
+8796 : r'uni225C',
+8455 : r'uni2107',
+8797 : r'uni225D',
+8798 : r'uni225E',
+8799 : r'uni225F',
+9788 : r'uni263C',
+8458 : r'uni210A',
+9790 : r'uni263E',
+9792 : r'uni2640',
+8800 : r'uni2260',
+9794 : r'uni2642',
+8459 : r'uni210B',
+8801 : r'uni2261',
+8460 : r'uni210C',
+8802 : r'uni2262',
+8461 : r'uni210D',
+8803 : r'uni2263',
+8462 : r'uni210E',
+8804 : r'uni2264',
+8805 : r'uni2265',
+9824 : r'uni2660',
+9825 : r'uni2661',
+9826 : r'uni2662',
+9827 : r'uni2663',
+9828 : r'uni2664',
+8806 : r'uni2266',
+9830 : r'uni2666',
+8465 : r'uni2111',
+9833 : r'uni2669',
+9834 : r'uni266A',
+8807 : r'uni2267',
+8920 : r'uni22D8',
+8466 : r'uni2112',
+9838 : r'uni266E',
+9839 : r'uni266F',
+8808 : r'uni2268',
+8852 : r'uni2294',
+8467 : r'uni2113',
+8809 : r'uni2269',
+8810 : r'uni226A',
+8469 : r'uni2115',
+9831 : r'uni2667',
+9835 : r'uni266B',
+8812 : r'uni226C',
+8921 : r'uni22D9',
+8890 : r'uni22BA',
+8813 : r'uni226D',
+8472 : r'uni2118',
+8814 : r'uni226E',
+8785 : r'uni2251',
+8473 : r'uni2119',
+8815 : r'uni226F',
+8474 : r'uni211A',
+8816 : r'uni2270',
+8475 : r'uni211B',
+8240 : r'perthousand',
+8922 : r'uni22DA',
+8476 : r'uni211C',
+8818 : r'uni2272',
+8477 : r'uni211D',
+8819 : r'uni2273',
+8478 : r'uni211E',
+8820 : r'uni2274',
+8821 : r'uni2275',
+8241 : r'uni2031',
+8923 : r'uni22DB',
+8263 : r'uni2047',
+8482 : r'trademark',
+8824 : r'uni2278',
+8825 : r'uni2279',
+8484 : r'uni2124',
+8826 : r'uni227A',
+8485 : r'uni2125',
+8242 : r'uni2032',
+8924 : r'uni22DC',
+8486 : r'uni2126',
+8828 : r'uni227C',
+8487 : r'uni2127',
+8877 : r'uni22AD',
+8829 : r'uni227D',
+8488 : r'uni2128',
+8830 : r'uni227E',
+8489 : r'uni2129',
+8831 : r'uni227F',
+8993 : r'uni2321',
+8243 : r'uni2033',
+8925 : r'uni22DD',
+8491 : r'uni212B',
+8833 : r'uni2281',
+8857 : r'uni2299',
+8492 : r'uni212C',
+8834 : r'uni2282',
+8493 : r'uni212D',
+8835 : r'uni2283',
+8494 : r'uni212E',
+8836 : r'uni2284',
+8495 : r'uni212F',
+8244 : r'uni2034',
+10016 : r'uni2720',
+8496 : r'uni2130',
+8891 : r'uni22BB',
+8838 : r'uni2286',
+8497 : r'uni2131',
+8839 : r'uni2287',
+8498 : r'uni2132',
+8840 : r'uni2288',
+8499 : r'uni2133',
+10038 : r'uni2736',
+8841 : r'uni2289',
+8500 : r'uni2134',
+9686 : r'uni25D6',
+8245 : r'uni2035',
+8501 : r'uni2135',
+8823 : r'uni2277',
+8843 : r'uni228B',
+8502 : r'uni2136',
+8844 : r'uni228C',
+8503 : r'uni2137',
+8845 : r'uni228D',
+8504 : r'uni2138',
+8846 : r'uni228E',
+12336 : r'uni3030',
+8246 : r'uni2036',
+8848 : r'uni2290',
+8849 : r'uni2291',
+8850 : r'uni2292',
+8851 : r'uni2293',
+8247 : r'uni2037',
+8853 : r'uni2295',
+8254 : r'uni203E',
+8854 : r'uni2296',
+8793 : r'uni2259',
+8855 : r'uni2297',
+8856 : r'uni2298',
+8248 : r'uni2038',
+9612 : r'uni258C',
+10139 : r'uni279B',
+8862 : r'uni229E',
+8859 : r'uni229B',
+9426 : r'uni24D2',
+8860 : r'uni229C',
+8861 : r'uni229D',
+8966 : r'uni2306',
+8249 : r'guilsinglleft',
+8892 : r'uni22BC',
+8522 : r'uni214A',
+9561 : r'uni2559',
+8865 : r'uni22A1',
+8866 : r'uni22A2',
+8250 : r'guilsinglright',
+8868 : r'uni22A4',
+8871 : r'uni22A7',
+8251 : r'uni203B',
+8933 : r'uni22E5',
+8606 : r'uni219E',
+
+}
+try:
+    from _mathtext_manual_data import _uni2type1
+    uni2type1.update(_uni2type1)
+except (TypeError, SyntaxError): # Just these exceptions should be raised
+    raise
+except: # All other exceptions should be silent. Even ImportError
+    pass
